@@ -13,6 +13,11 @@
 ((Sazanami\ Mincho sansserif) (Sazanami\ Gothic))
 ((SimSun bold) (SimHei))
 ((SimSun sansserif) (SimHei))
+((SimSun italic) (KaiTi_GB2312))
+((SimSun typewriter) (FangSong_GB2312))
+
+((Songti\ SC sansserif) (PingFang\ SC))
+
 ((STSong bold) (STHeiti))
 ((STSong sansserif) (STHeiti))
 ((STSong italic) (STKaiti))
@@ -31,3 +36,15 @@
 ((roman cjk) (SimSun))
 ((Stix cjk) (FandolSong))
 ((Stix cjk) (SimSun))
+
+((Bodoni\ 72 smallcaps) (Bodoni\ 72\ Smallcaps))
+((Bodoni\ 72\ Oldstyle smallcaps) (Bodoni\ 72\ Smallcaps))
+((Linux\ Libertine sansserif) (Linux\ Biolinum))
+((TeX\ Gyre\ Pagella typewriter) (roman typewriter))
+
+((Calibri typewriter) (Consolas))
+((Cambria sansserif) (Calibri))
+((Cambria typewriter) (Consolas))
+((Constantia sansserif) (Corbel))
+((Constantia typewriter) (Consolas))
+((Corbel typewriter) (Consolas))
