@@ -431,46 +431,60 @@
 ("#2126" "{\\textohm}")
 ("#2127" "{\\textmho}")
 ("#212E" "{\\textestimated}")
-("#2190" "{\\textleftarrow}")
-("#2191" "{\\textuparrow}")
-("#2192" "{\\textrightarrow}")
-("#2193" "{\\textdownarrow}")
-("#2329" "{\\textlangle}")
-("#232A" "{\\textrangle}")
-("#2422" "{\\textblank}")
-("#2423" "{\\textvisiblespace}")
-("#25E6" "{\\textopenbullet}")
-("#25EF" "{\\textbigcircle}")
-("#266A" "{\\textmusicalnote}")
-("#1D6FC" "{\\ensuremath{alpha}}")
-("#1D6FD" "{\\ensuremath{beta}}")
-("#1D6FE" "{\\ensuremath{gamma}}")
-("#1D6FF" "{\\ensuremath{delta}}")
-("#1D700" "{\\ensuremath{varepsilon}}")
-("#1D701" "{\\ensuremath{zeta}}")
-("#1D702" "{\\ensuremath{eta}}")
-("#1D703" "{\\ensuremath{theta}}")
-("#1D704" "{\\ensuremath{iota}}")
-("#1D705" "{\\ensuremath{kappa}}")
-("#1D706" "{\\ensuremath{lambda}}")
-("#1D707" "{\\ensuremath{mu}}")
-("#1D708" "{\\ensuremath{nu}}")
-("#1D709" "{\\ensuremath{xi}}")
-("#1D70A" "{\\ensuremath{omicron}}")
-("#1D70B" "{\\ensuremath{pi}}")
-("#1D70C" "{\\ensuremath{rho}}")
-("#1D70D" "{\\ensuremath{varsigma}}")
-("#1D70E" "{\\ensuremath{sigma}}")
-("#1D70F" "{\\ensuremath{tau}}")
-("#1D710" "{\\ensuremath{upsilon}}")
-("#1D711" "{\\ensuremath{varphi}}")
-("#1D712" "{\\ensuremath{chi}}")
-("#1D713" "{\\ensuremath{psi}}")
-("#1D714" "{\\ensuremath{omega}}")
-("#1D715" "{\\ensuremath{partial}}")
-("#1D716" "{\\ensuremath{epsilon}}")
-("#1D717" "{\\ensuremath{vartheta}}")
-("#1D718" "{\\ensuremath{varkappa}}")
-("#1D719" "{\\ensuremath{phi}}")
-("#1D71A" "{\\ensuremath{varrho}}")
-("#1D71B" "{\\ensuremath{varpi}}")
+("#2190" "{\\ensuremath{\\leftarrow}}")
+("#2191" "{\\ensuremath{\\uparrow}}")
+("#2192" "{\\ensuremath{\\rightarrow}}")
+("#2193" "{\\ensuremath{\\downarrow}}")
+("#2196" "{\\ensuremath{\\nwarrow}}")
+("#2198" "{\\ensuremath{\\searrow}}")
+("#21A9" "{\\ensuremath{\\hookleftarrow}}")
+("#21DE" "{PageUp }")
+("#21DF" "{PageDown }")
+("#21E5" "{\\ensuremath{\\rightarrow\\shortmid}}") ;; FIXME: Hack for tab key
+("#21E7" "{\\ensuremath{\\Uparrow}}")              ;; FIXME: Hack for shift key
+("#21EA" "{CapsLock }")
+("#2303" "{Ctrl }")
+("#2318" "{Cmd }")
+("#2325" "{Alt }")
+("#2326" "{Del }")
+("#2329" "{\\ensuremath{\\langle}}")
+("#232A" "{\\ensuremath{\\rangle}}")
+("#232B" "{Bksp }")
+("#2422" "{\\ensuremath{\\blank}}")
+("#2423" "{\\;\\;}")                           ;; FIXME: hack for \visiblespace
+("#238B" "{Esc }")
+("#25E6" "{\\ensuremath{\\openbullet}}")
+("#25EF" "{\\ensuremath{\\bigcircle}}")
+("#266A" "{\\ensuremath{\\musicalnote}}")
+("#1D6FC" "{\\ensuremath{\\alpha}}")
+("#1D6FD" "{\\ensuremath{\\beta}}")
+("#1D6FE" "{\\ensuremath{\\gamma}}")
+("#1D6FF" "{\\ensuremath{\\delta}}")
+("#1D700" "{\\ensuremath{\\varepsilon}}")
+("#1D701" "{\\ensuremath{\\zeta}}")
+("#1D702" "{\\ensuremath{\\eta}}")
+("#1D703" "{\\ensuremath{\\theta}}")
+("#1D704" "{\\ensuremath{\\iota}}")
+("#1D705" "{\\ensuremath{\\kappa}}")
+("#1D706" "{\\ensuremath{\\lambda}}")
+("#1D707" "{\\ensuremath{\\mu}}")
+("#1D708" "{\\ensuremath{\\nu}}")
+("#1D709" "{\\ensuremath{\\xi}}")
+("#1D70A" "{\\ensuremath{\\omicron}}")
+("#1D70B" "{\\ensuremath{\\pi}}")
+("#1D70C" "{\\ensuremath{\\rho}}")
+("#1D70D" "{\\ensuremath{\\varsigma}}")
+("#1D70E" "{\\ensuremath{\\sigma}}")
+("#1D70F" "{\\ensuremath{\\tau}}")
+("#1D710" "{\\ensuremath{\\upsilon}}")
+("#1D711" "{\\ensuremath{\\varphi}}")
+("#1D712" "{\\ensuremath{\\chi}}")
+("#1D713" "{\\ensuremath{\\psi}}")
+("#1D714" "{\\ensuremath{\\omega}}")
+("#1D715" "{\\ensuremath{\\partial}}")
+("#1D716" "{\\ensuremath{\\epsilon}}")
+("#1D717" "{\\ensuremath{\\vartheta}}")
+("#1D718" "{\\ensuremath{\\varkappa}}")
+("#1D719" "{\\ensuremath{\\phi}}")
+("#1D71A" "{\\ensuremath{\\varrho}}")
+("#1D71B" "{\\ensuremath{\\varpi}}")
