@@ -1468,15 +1468,15 @@ veg msolsa")
 ("the application does not reply" "az alkalmazs nem vlaszol")
 ("the application is already running" "az alkalmazs mr fut")
 ("the boxes produced by the typesetter" "a szed ltal ksztett dobozok")
-("the buffer has not been saved" "a puffer nincs elmentve")
+("the document has not been saved" "a puffer nincs elmentve")
 ("the graphical user interface" "a grafikus felhasznli fellet")
 ("the leaves of TeXmacs trees" "")
 ("the mycas example" "a mycas plda")
 ("the primitive TeXmacs constructs" "")
 ("the standard TeXmacs styles" "a standard TeXmacs stlusok")
 ("theorem" "ttel")
-("there are unsaved files" "vannak mentsre vr fjlok")
-("this buffer has not been saved" "ez a puffer mg nincs elmentve")
+("there are unsaved documents" "vannak mentsre vr fjlok")
+("this document has not been saved" "ez a puffer mg nincs elmentve")
 ("this column" "ez az oszlop")
 ("this document has been produced using" "")
 ("this line" "ezt a sort")
