@@ -9,7 +9,7 @@
 ("about" "")
 ("about menu" "")
 ("above" "")
-("abreviated authors" "")
+("abbreviated authors" "")
 ("abstract" "")
 ("accent" "")
 ("accent above" "")
@@ -302,6 +302,7 @@
 ("break" "")
 ("breaking" "")
 ("breve" "")
+("bright" "")
 ("british" "")
 ("broken citations" "")
 ("broken references" "")
@@ -605,6 +606,7 @@
 ("czech" "")
 ("dancers" "")
 ("danish" "")
+("dark" "")
 ("dark grey" "")
 ("dark-vador" "")
 ("dash" "")
@@ -2268,9 +2270,11 @@
 ("prompt on scripts" "")
 ("prompts and default input" "")
 ("proof" "")
+("proofs" "")
 ("properties" "")
 ("proportional" "")
 ("proportional typewriter" "")
+("property" "")
 ("proposition" "")
 ("propositions" "")
 ("provoke C++ error" "")
@@ -2517,6 +2521,8 @@
 ("save verbatim file" "")
 ("saved" "")
 ("saved modifications in database" "")
+("scale of the graphical user interface" "")
+("scale graphical interface" "")
 ("scheme command" "")
 ("scheme developers guide" "")
 ("scheme extensions" "")
@@ -2672,6 +2678,7 @@
 ("slide" "")
 ("slides" "")
 ("sloppy" "")
+("slovak" "")
 ("slovene" "")
 ("slow" "")
 ("slow decrease" "")
@@ -2878,7 +2885,6 @@
 ("teXmacs fonts" "")
 ("teXmacs macro" "")
 ("teXmacs manual" "")
-("teXmacs manuel" "")
 ("teXmacs notice" "")
 ("teXmacs package" "")
 ("teXmacs plugins" "")
@@ -3142,6 +3148,7 @@
 ("use very large font size" "")
 ("user interface" "")
 ("user interface language" "")
+("user interface theme" "")
 ("user manual" "")
 ("user preferences" "")
 ("user provided icons" "")
@@ -3223,6 +3230,7 @@
 ("window" "")
 ("window height" "")
 ("window width" "")
+("windows" "")
 ("windows key" "")
 ("with" "")
 ("with newer version" "")
