@@ -3,8 +3,8 @@
 ;;
 ;; MODULE      : init-dratex.scm
 ;; DESCRIPTION : Initialize DraTex plugin
-;; COPYRIGHT   : (C) 2005 Nicolas Ratier
-;;               (C) 2019 Darcy Shen
+;; COPYRIGHT   : (C) 2005       Nicolas Ratier
+;;               (C) 2019-2020  Darcy Shen
 ;;
 ;; This software falls under the GNU general public license version 3 or later.
 ;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
@@ -19,14 +19,15 @@
 
 (define (dratex-launcher)
   (if (url-exists? "$TEXMACS_HOME_PATH/plugins/tmpy")
-      (string-append "python3.7 \""
+      (string-append (python-command) " \""
                      (getenv "TEXMACS_HOME_PATH")
                      "/plugins/tmpy/session/tm_dratex.py\"")
-      (string-append "python3.7 \""
+      (string-append (python-command) " \""
                      (getenv "TEXMACS_PATH")
                      "/plugins/tmpy/session/tm_dratex.py\"")))
 
 (plugin-configure dratex
+  (:require (python-command))
   (:require (url-exists-in-path? "latex"))
   (:launch ,(dratex-launcher))
   (:serializer ,dratex-serialize)
