@@ -15,13 +15,6 @@
       (with s (texmacs->code (stree->tree u) "SourceCode")
         (string-append  s  "\n<EOF>\n"))))
 
-(define (python-command)
-  (if (url-exists-in-path? "python3") "python3" "python2"))
-
-(define (python-exists?)
-  (or (url-exists-in-path? "python3")
-      (url-exists-in-path? "python2")))
-
 (define (graph-launcher)
   (if (url-exists? "$TEXMACS_HOME_PATH/plugins/tmpy")
       (string-append (python-command) " \""
@@ -32,7 +25,7 @@
                      "/plugins/tmpy/session/tm_graph.py\"")))
 
 (plugin-configure graph
-  (:require (python-exists?))
+  (:require (python-command))
   (:launch ,(graph-launcher))
   (:serializer ,graph-serialize)
   (:session "Graph"))
