@@ -13,5 +13,5 @@ function flush_any (output)
   DATA_BEGIN= 2;
   DATA_END= 5;
   surrounded= sprintf ("%c%s%c", DATA_BEGIN, output, DATA_END);
-  disp (surrounded);
+  printf (surrounded);
 endfunction
