@@ -103,7 +103,7 @@ jmp_buf error_return_env ;
 
 int N_data_begins = 0 ;
 
-char *DEFAULT_TEXMACS_SEND = "";
+char *DEFAULT_TEXMACS_SEND = "source(paste(Sys.getenv(\"TEXMACS_PATH\"),\"/plugins/r/texmacs.r\",sep=\"\"))\n";
 
 
 // Add one more DATA_BEGIN, i.e. open bracket.
@@ -852,6 +852,11 @@ int main(int argc, char *argv[])
     snprintf( TEXMACS_HOME_PATH, 4096, "%s/.TeXmacs",HOME) ;
   }
   
+  /* Lazy installing the TeXmacs package */
+  TEXMACS_LIB = (char *)malloc(4096);
+  snprintf(TEXMACS_LIB,4096,"%s/plugins/r/r",TEXMACS_HOME_PATH);
+  if (stat(TEXMACS_LIB,&stat_buf))
+    system("r_install"); 
 
   setenv( "TERM", "dumb", 1) ;
   
