@@ -1,4 +1,4 @@
-#!/usr/local/bin/python3.7
+#!/usr/bin/env python
 ###############################################################################
 ##
 ## MODULE      : tikz.py
@@ -29,9 +29,21 @@ class TikZ(LaTeX):
 """
         self.message = "TeXmacs interface to TikZ"
 
+    def available(self):
+        if not super(TikZ, self).available():
+            return False
+        for sty in ("standalone", "tikz"):
+            if len (super(TikZ, self).kpsewhich(sty + ".sty")) <= 0:
+                flush_err ("Failed to find " + sty +".sty,"
+                           " please install the missing LaTeX packages\n")
+                return False
+        return True
+        
     def evaluate(self, code):
         if not (code.lstrip().startswith("\\documentclass")):
-            if not (code.lstrip().startswith("\\begin{tikzpicture}")):
+            if code.lstrip().startswith("\\usetikzlibrary"):
+                pass
+            elif not (code.lstrip().startswith("\\begin{tikzpicture}")):
                 code = "\\begin{tikzpicture}\n" + code + "\n\\end{tikzpicture}"
             code = self.pre_code + "\n" + code + "\n" + self.post_code
 
