@@ -195,14 +195,15 @@
       ======
       (aligned
 	(item (text "Server:")
-	  (form-enum "server"
-                     (if (== server-name "")
-                         (rcons (tm-servers) "")
-                         (cons server-name (rcons (tm-servers) "")))
-                     (if (== server-name "")
-                         (car (tm-servers))
-                         server-name)
-                     "280px"))
+	  (verb
+            (form-enum "server"
+                       (if (== server-name "")
+                           (rcons (tm-servers) "")
+                           (cons server-name (rcons (tm-servers) "")))
+                       (if (== server-name "")
+                           (car (tm-servers))
+                           server-name)
+                       "280px")))
 	(item (text "Pseudo:")
 	  (form-input "pseudo" "string"
 		      (list pseudo) "300px"))
@@ -824,7 +825,7 @@
 		   ;;(display* "Remote : " remote-name "\n")
 		   ;;(display* "Message: " message "\n")
 		   (remote-upload local-name remote-name message
-                                  (lambda x (revert-buffer)))))
+                                  (lambda x (revert-buffer-revert)))))
 	     (quit))))))))
 
 (tm-define (remote-interactive-upload server)
@@ -895,7 +896,7 @@
     (with remote-name (url-append remote-dir (url-tail local-name))
       (remote-upload local-name remote-name "uploaded"
                      (lambda x
-                       (revert-buffer)
+                       (revert-buffer-revert)
                        (set-message "upload completed" "upload"))))))
 
 (tm-define (simple-interactive-upload server)
