@@ -353,6 +353,20 @@
       '()
       '((next-line))))
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; MathJax extension
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
+(define (htmltm-mathjax env a c)
+  (if (and (list-1? c) (string? (car c)) (string->number (car c)))
+      (let* ((id (string->number (car c)))
+             (t (retrieve-mathjax id))
+             (s (tree->string t))
+             (l (parse-latex s))
+             (r (latex->texmacs l)))
+        (list (tm->stree r)))
+      (htmltm-drop env a c)))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Special rules for improving Wikipedia rendering
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -369,9 +383,13 @@
       (htmltm-image env a c)))
 
 (define (htmltm-wikipedia-span env a c)
-  (if (== (shtml-attr-non-null a 'class) "texhtml")
-      (list `(math ,(htmltm-args-serial env c)))
-      (htmltm-pass env a c)))
+  (cond ((== (shtml-attr-non-null a 'class) "mwe-math-element")
+         (if (and (pair? c) (func? (car c) 'h:span))
+             (htmltm env (car c))
+             (htmltm-pass env a c)))
+        ((== (shtml-attr-non-null a 'class) "texhtml")
+         (list `(math ,(htmltm-args-serial env c))))
+        (else (htmltm-pass env a c))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Special rules for improving Scilab documentation rendering
@@ -436,12 +454,12 @@
   (span (handler :collapse :inline htmltm-wikipedia-span))
 
   ;; Headings
-  (h1 (handler :mixed :block "chapter"))
-  (h2 (handler :mixed :block "section"))
-  (h3 (handler :mixed :block "subsection"))
-  (h4 (handler :mixed :block "subsubsection"))
-  (h5 (handler :mixed :block "paragraph"))
-  (h6 (handler :mixed :block "subparagraph"))
+  (h1 (handler :mixed :block "chapter*"))
+  (h2 (handler :mixed :block "section*"))
+  (h3 (handler :mixed :block "subsection*"))
+  (h4 (handler :mixed :block "subsubsection*"))
+  (h5 (handler :mixed :block "paragraph*"))
+  (h6 (handler :mixed :block "subparagraph*"))
 
   ;; Address and text direction
   (address (handler :mixed :block htmltm-pass))
@@ -544,6 +562,9 @@
   (script htmltm-drop)
   (noscript (handler :mixed :block htmltm-pass))
 
+  ;;; Extensions
+  (mathjax (handler :collapse :inline htmltm-mathjax))
+  
   ;; Tags present in the previous converter
   ;; Unknown: FIG FN NOTE AU LANG PERSON
   ;; ABBREV instead of ABBR
@@ -608,9 +629,7 @@
 (tm-define (parse-html-document s)
   `(!file ,(htmltm-parse s)))
 
-(tm-define (html->texmacs html)
-  (:type (-> stree stree))
-  (:synopsis "Convert a parsed HTML stree @t into a TeXmacs stree.")
+(define (convert-html-texmacs html)
   (let* ((snippet? (not (func? html '!file 1)))
 	 (body (if snippet? html (cadr html)))
 	 (tm (html-postproc (htmltm-as-serial (sxhtml-correct-table body)))))
@@ -620,3 +639,8 @@
 	       (body `(body ,doc))
 	       (style `(style "browser")))
 	  `(document ,body ,style)))))
+
+(tm-define (html->texmacs html)
+  (:type (-> stree stree))
+  (:synopsis "Convert a parsed HTML stree @t into a TeXmacs stree.")
+  (tree->stree (clean-html (convert-html-texmacs html))))
