@@ -26,6 +26,7 @@
 (define latex-language "english")
 (define latex-style "generic")
 (define latex-packages '())
+(define latex-extra-packages '())
 (define latex-virtual-packages '())
 (define latex-all-packages '())
 (define latex-texmacs-style "generic")
@@ -54,6 +55,15 @@
   (set! latex-packages ps)
   (latex-set-dependencies))
 
+(tm-define (latex-set-extra ps)
+  (set! latex-extra-packages ps)
+  (latex-set-dependencies))
+
+(tm-define (latex-add-extra p)
+  (when (nin? p latex-extra-packages)
+    (set! latex-extra-packages (cons p latex-extra-packages))
+    (latex-set-dependencies)))
+
 (tm-define (latex-set-virtual-packages ps)
   (set! latex-virtual-packages ps)
   (latex-set-dependencies))
@@ -66,7 +76,9 @@
 
 (define (latex-set-dependencies)
   (set! latex-all-packages
-        (list-remove-duplicates (append latex-packages latex-virtual-packages)))
+        (list-remove-duplicates (append latex-packages
+                                        latex-extra-packages
+                                        latex-virtual-packages)))
   (set! latex-dependencies
         (latex-packages-dependencies (cons latex-style latex-all-packages))))
 
@@ -412,7 +424,13 @@
 (define (latex-use-which-package l)
   (when (and (list? l) (nnull? l))
     (let ((x (car l)))
-      (if (symbol? x) (latex-command-uses x))
+      (when (symbol? x)
+        (with s (symbol->string x)
+          (cond ((string-starts? s "left\\")
+                 (latex-command-uses (string->symbol (string-drop s 5))))
+                ((string-starts? s "right\\")
+                 (latex-command-uses (string->symbol (string-drop s 6))))
+                (else (latex-command-uses x)))))
       (if (and (list? x) (>= (length l) 2) (== (car x) '!begin))
 	  (latex-command-uses
            (string->symbol (string-append "begin-" (cadr x)))))
@@ -428,10 +446,10 @@
     (< vl vr)))
 
 (define (filter-packages l)
-  (filter (lambda (x) (nin? x tmtex-provided-packages)) l))
+  (filter (lambda (x) (nin? x (tmtex-provided-packages))) l))
 
 (define (filter-packages* l)
-  (filter (lambda (x) (nin? (cAr x) tmtex-provided-packages)) l))
+  (filter (lambda (x) (nin? (cAr x) (tmtex-provided-packages))) l))
 
 (define (make-use-package l)
   (with po (ahash-ref latex-packages-option (cAr l))
@@ -441,7 +459,10 @@
       (with opts (if (== opt "") "" (string-append "["  opt "]"))
         (string-append "\\usepackage" opts "{" sty "}\n")))))
 
-(define (latex-as-use-package l1)
+(tm-define (latex-ifacconf-style?)
+  (== tmtex-style "ifacconf"))
+
+(tm-define (latex-as-use-package l1)
   (let* ((l2  (sort l1 latex-use-package-compare))
 	 (l3  (filter
                 (lambda (x)
@@ -536,6 +557,8 @@
         ((nnull? colors)
          (ahash-set! latex-packages-option pack (list "")))))
 
+(tm-define (latex-extra-preamble) "")
+
 (tm-define (latex-preamble text style lan init colors colormaps)
   (:synopsis "Compute preamble for @text")
   (with-global tmtex-style (if (list? style) (cAr style) style)
@@ -549,13 +572,14 @@
            (pre-macro    (latex-serialize-preamble Macro))
            (pre-colors   (latex-serialize-preamble Colors))
            (pre-catcode  (latex-catcode-defs Text))
-           (pre-uses     (latex-use-package-command Text)))
+           (pre-uses     (latex-use-package-command Text))
+           (pre-extra    (latex-extra-preamble)))
       (values
         (cond ((and (in? "amsthm" latex-all-packages)
                     (== style "amsart")) "[amsthm]")
               ((list? style) (latex-make-option (cDr style)))
               (else ""))
-        (string-append pre-uses)
+        (string-append pre-uses pre-extra)
         (string-append pre-page)
         (string-append pre-catcode pre-macro pre-colors)))))
 
@@ -563,15 +587,16 @@
 ;; Clean-up the produced LaTeX for use with MathJax
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-(define (latex-mathjax-text l x)
-  (cond ((or (npair? x) (nlist? x)) `(,l ,x))
-        ((func? x 'tmtextsf 1) (latex-mathjax-text 'textsf (cadr x)))
-        ((func? x 'tmtexttt 1) (latex-mathjax-text 'texttt (cadr x)))
-        ((func? x 'tmtextit 1) (latex-mathjax-text 'textit (cadr x)))
-        ((func? x 'tmtextbf 1) (latex-mathjax-text 'textbf (cadr x)))
-        ((func? x 'tmtextrm 1) (latex-mathjax-text l (cadr x)))
-        ((func? x 'tmtextup 1) (latex-mathjax-text l (cadr x)))
-        (else `(,l ,x))))
+(define (latex-mathjax-text l arg)
+  (with x (latex-mathjax-pre arg)
+    (cond ((or (npair? x) (nlist? x)) `(,l ,x))
+          ((func? x 'tmtextsf 1) (latex-mathjax-text 'textsf (cadr x)))
+          ((func? x 'tmtexttt 1) (latex-mathjax-text 'texttt (cadr x)))
+          ((func? x 'tmtextit 1) (latex-mathjax-text 'textit (cadr x)))
+          ((func? x 'tmtextbf 1) (latex-mathjax-text 'textbf (cadr x)))
+          ((func? x 'tmtextrm 1) (latex-mathjax-text l (cadr x)))
+          ((func? x 'tmtextup 1) (latex-mathjax-text l (cadr x)))
+          (else `(,l ,x)))))
 
 (tm-define (latex-mathjax-pre x)
   (:synopsis "Produce cleaner LaTeX for @x for use with MathJax, pass 1")
@@ -585,6 +610,7 @@
         ((func? x 'dotplus 0) `(dot "+"))
         ((func? x 'dottimes 0) `(dot (times)))
         ((func? x 'dotast 0) `(dot (ast)))
+        ((func? x 'dag) `(dagger))
         ((and (func? x 'color 2) (func? (cadr x) '!option 1))
          ;; NOTE : MathJax has broken color support, so ignore certain colors
          ;; FIXME: this hack may have to be suppressed when MathJax improves
