@@ -70,7 +70,7 @@
   (for (name (session-list))
     (with menu-name (session-name name)
       ((eval menu-name)
-       (insert-go-to `(script-input ,name "default" "" "") '(2 0))))))
+       (make-script-input* name "default")))))
 
 (menu-bind insert-fold-menu
   (-> "Folded"
@@ -392,6 +392,7 @@
           (vlist
             ("Color" (interactive-color setter (list)))
             ("Pattern" (open-pattern-selector setter "1cm"))
+            ("Gradient" (open-gradient-selector setter))
             ("Picture" (open-background-picture-selector setter))
             (glue #f #t 0 0))))
       ======
