@@ -385,7 +385,7 @@
 	      ("Bold" (make-with "math-font-series" "bold"))))
       (-> "Shape"
 	  ("Normal" (make-with "math-font-shape" "normal"))
-	  ("Upight" (make-with "math-font-shape" "right"))))
+	  ("Upright" (make-with "math-font-shape" "right"))))
   (if (not (real-math-font? (get-env "math-font")))
       (-> "Variant"
 	  ("Roman" (make-with "math-font-family" "mr"))
