@@ -48,12 +48,16 @@
         ((tree-func? t 'document 1)
          (with-simplify-sub (tree-up t) var))
         ((tree-func? t 'with)
-         (with-simplify-sub (tree-up t) var)
          (for (i (reverse (.. 0 (quotient (tree-arity t) 2))))
            (when (== (tree-ref t (* 2 i)) var)
              (tree-remove! t (* 2 i) 2)))
+         (when (and (tree-func? (tm-ref t :last) 'document 1)
+                    (tree-func? (tm-ref t :last 0) 'with))
+           (tree-remove-node (tm-ref t :last) 0))
          (when (tree-func? t 'with 1)
-           (tree-remove-node! t 0)))))
+           (tree-remove-node! t 0))
+         (when (tree-up t)
+           (with-simplify-sub (tree-up t) var)))))
 
 (tm-define (with-simplify t)
   (when (and (not (tree-is-buffer? t)) (tree->path t))
@@ -95,6 +99,12 @@
         `(with ,@(cDr c) ,(add-with l (cAr c))))
       `(with ,@l ,t)))
 
+(define (add-with-path l t)
+  (if (tm-is? t 'with)
+      (with c (tm-children t)
+        (cons (length (cDr c)) (add-with-path l (cAr c))))
+      (cons (length l) (path-end t '()))))
+
 (define (get-cars l)
   (if (or (null? l) (null? (cdr l))) (list)
       (cons (car l) (get-cars (cddr l)))))
@@ -105,12 +115,19 @@
 
 (tm-define (make-multi-with l)
   (when (nnull? l)
-    (if (selection-active-table?)
-        (for-each cell-set-format (get-cars l) (get-cadrs l))
-        (with t (if (selection-active-any?) (selection-tree) "")
-          (if (selection-active-any?) (clipboard-cut "null"))
-          (insert-go-to (add-with l t) (cons (length l) (path-end t '())))
-          (with-simplify (cursor-tree))))))
+    (cond ((selection-active-table?)
+           (keep-table-selection
+            (for-each cell-set-format (get-cars l) (get-cadrs l))))
+          ((selection-active-any?)
+           (with t (selection-tree)
+             (clipboard-cut "null")
+             (insert-go-to (add-with l t) (add-with-path l t))
+             (with-simplify (cursor-tree))
+             (and-with w (tree-innermost 'with #t)
+               (tree-select w))))
+          (else
+            (insert-go-to `(with ,@l "") (list (length l) 0))
+            (with-simplify (cursor-tree))))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Modifying paragraph properties
@@ -135,14 +152,20 @@
 
 (tm-define (make-multi-line-with l)
   (when (nnull? l)
-    (if (and (selection-active-table?) #f) ;; FIXME: does not work yet
-        (make-multi-with l)
-        (begin
-          (when (not (selection-active-normal?))
-            (select-line))
-          (make-multi-with l)
-          (insert-return)
-          (remove-text #f)))))
+    (cond ((selection-active-table?)
+           (make-multi-with l))
+          (else
+            (when (not (selection-active-normal?))
+              (select-line))
+            (make-multi-with l)
+            (insert-return)
+            (remove-text #f)
+            (and-with w (tree-innermost 'with #t)
+              (with-simplify w)
+              (and-with w* (tree-innermost 'with #t)
+                (with-merge w*)
+                (and-with w** (tree-innermost 'with #t)
+                  (tree-select w**))))))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Inserting and toggling with-like tags
@@ -180,7 +203,7 @@
 	((selection-active-any?)
 	 (let* ((selection (selection-tree))
 		(ins `(,@(cDr w) ,selection))
-		(end (path-end ins '())))
+		(end (path-end selection '())))
 	   (clipboard-cut "nowhere")
 	   (insert-go-to ins (cons (- (tm-arity ins) 1) end))))
 	(else
@@ -333,6 +356,10 @@
 ;; Font effects
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
+(tm-define (parameter-choice-list var)
+  (:require (in? var (list "embold-strength" "embbb-strength")))
+  (list "1.5" "2" "2.5" "3" "4" "5" :other))
+
 (tm-define (customizable-parameters t)
   (:require (tree-is? t 'embold))
   (list (list "embold-strength" "Strength")))
@@ -341,10 +368,19 @@
   (:require (tree-is? t 'embbb))
   (list (list "embbb-strength" "Strength")))
 
+(tm-define (parameter-choice-list var)
+  (:require (in? var (list "slanted-slope")))
+  (list "-1" "-0.5" "-0.33" "-0.25" "-0.2" "-0.15" "-0.1"
+        "0.1" "0.15" "0.2" "0.25" "0.33" "0.5" "1" :other))
+
 (tm-define (customizable-parameters t)
   (:require (tree-is? t 'slanted))
   (list (list "slanted-slope" "Slope")))
 
+(tm-define (parameter-choice-list var)
+  (:require (string-ends? var "magnified-factor"))
+  (list "0.2" "0.5" "0.8" "0.9" "1.1" "1.2" "1.5" "2" "5" :other))
+
 (tm-define (customizable-parameters t)
   (:require (tree-is? t 'hmagnified))
   (list (list "hmagnified-factor" "Factor")))
@@ -353,19 +389,47 @@
   (:require (tree-is? t 'vmagnified))
   (list (list "vmagnified-factor" "Factor")))
 
+(tm-define (parameter-choice-list var)
+  (:require (== var "condensed-factor"))
+  (list "0.5" "0.75" "0.8" "0.85" "0.9" "0.95" :other))
+
 (tm-define (customizable-parameters t)
   (:require (tree-is? t 'condensed))
   (list (list "condensed-factor" "Factor")))
 
+(tm-define (parameter-choice-list var)
+  (:require (== var "extended-factor"))
+  (list "1.05" "1.1" "1.15" "1.2" "1.25" "1.5" "2" :other))
+
 (tm-define (customizable-parameters t)
   (:require (tree-is? t 'extended))
   (list (list "extended-factor" "Factor")))
 
+(tm-define (parameter-choice-list var)
+  (:require (== var "monospaced-factor"))
+  (list "0.6" "0.65" "0.7" "0.75" "0.8" "0.85" "0.9" "0.95" "1" :other))
+
+(tm-define (customizable-parameters t)
+  (:require (tree-is? t 'extended))
+  (list (list "monospaced-factor" "Factor")))
+
+(tm-define (parameter-choice-list var)
+  (:require (== var "degraded-threshold"))
+  (list "0.5" "0.6" "0.667" "0.75" :other))
+
+(tm-define (parameter-choice-list var)
+  (:require (string-ends? var "-frequency"))
+  (list "0.5" "0.75" "1.0" "1.5" "2.0" :other))
+
 (tm-define (customizable-parameters t)
   (:require (tree-is? t 'degraded))
   (list (list "degraded-threshold" "Threshold")
         (list "degraded-frequency" "Frequency")))
 
+(tm-define (parameter-choice-list var)
+  (:require (in? var (list "distorted-strength" "gnawed-strength")))
+  (list "0.4" "0.5" "0.6" "0.8" "1.0" "1.5" :other))
+
 (tm-define (customizable-parameters t)
   (:require (tree-is? t 'distorted))
   (list (list "distorted-strength" "Strength")
@@ -380,6 +444,18 @@
 ;; Effects
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
+(tm-define (parameter-choice-list var)
+  (:require (or (string-ends? var "-pen-width")
+                (string-ends? var "-pen-height")
+                (string-ends? var "-pen-dx")
+                (string-ends? var "-pen-dy")
+                (string-ends? var "-blur-radius")))
+  (list "0.25ln" "0.5ln" "1ln" "1.5ln" "2ln" "2.5ln" "5ln" :other))
+
+(tm-define (parameter-choice-list var)
+  (:require (string-ends? var "-pen-angle"))
+  (list "-60" "-45" "-30" "0" "30" "45" "60" "90" :other))
+
 (tm-define (customizable-parameters t)
   (:require (tree-in? t '(blur gaussian-blur oval-blur rectangular-blur)))
   (list (list "blur-pen-width" "Pen width")
@@ -426,6 +502,13 @@
   (list (list "erode-pen-dx" "Pen dx")
         (list "erode-pen-dy" "Pen dy")))
 
+(tm-define (parameter-choice-list var)
+  (:require (in? var (list "shadow-dx" "shadow-dy"
+                           "engrave-dx" "engrave-dy"
+                           "emboss-dx" "emboss-dy")))
+  (list "-2.5ln" "-2ln" "-1.5ln" "-1ln" "-0.5ln" "0ln"
+        "0.5ln" "1ln" "1.5ln" "2ln" "2.5ln" :other))
+
 (tm-define (customizable-parameters t)
   (:require (tree-in? t '(shadow shadowed-raise)))
   (list (list "shadow-dx" "Dx")
@@ -461,6 +544,19 @@
         (list "outline-pen-height" "Pen height")
         (list "outline-pen-angle" "Pen angle")))
 
+(tm-define (parameter-choice-list var)
+  (:require (or (string-ends? var "-wavelen-x")
+                (string-ends? var "-wavelen-y")))
+  (list "0.1fn" "0.15fn" "0.2fn" "0.25fn" "0.3fn" "0.4fn" "0.5fn" :other))
+
+(tm-define (parameter-choice-list var)
+  (:require (== var "degrade-threshold"))
+  (list "0.5" "0.6" "0.667" "0.75" :other))
+
+(tm-define (parameter-choice-list var)
+  (:require (== var "degrade-sharpness"))
+  (list "0.5" "0.75" "1.0" "1.5" "2.0" :other))
+
 (tm-define (customizable-parameters t)
   (:require (tree-in? t '(degrade)))
   (list (list "degrade-wavelen-x" "Wave length x")
@@ -468,6 +564,11 @@
         (list "degrade-threshold" "Threshold")
         (list "degrade-sharpness" "Sharpness")))
 
+(tm-define (parameter-choice-list var)
+  (:require (in? var (list "distort-radius-x" "distort-radius-y"
+                           "gnaw-radius-x" "gnaw-radius-y")))
+  (list "0.05fn" "0.1fn" "0.15fn" "0.2fn" :other))
+
 (tm-define (customizable-parameters t)
   (:require (tree-in? t '(distort)))
   (list (list "distort-wavelen-x" "Wave length x")
@@ -482,6 +583,23 @@
         (list "gnaw-radius-x" "Radius x")
         (list "gnaw-radius-y" "Radius y")))
 
+(tm-define (customizable-parameters t)
+  (:require (tree-in? t '(make-transparent)))
+  (list (list "make-transparent-bg-color" "Background color")
+        (list "make-transparent-threshold" "Threshold")))
+
+(tm-define (customizable-parameters t)
+  (:require (tree-in? t '(make-opaque)))
+  (list (list "make-opaque-bg-color" "Background color")))
+
+(tm-define (customizable-parameters t)
+  (:require (tree-in? t '(recolor)))
+  (list (list "recolor-color" "New color")))
+
+(tm-define (customizable-parameters t)
+  (:require (tree-in? t '(skin)))
+  (list (list "skin-color" "Skin color")))
+
 (tm-define (pen-effect-context? t)
   (tree-in? t (pen-effect-tag-list)))
 
