@@ -45,7 +45,8 @@
 	    ($if (== s "body")
 		 "The main body of the macro."
 		 ($begin
-		   "An argument of type ``" (tree-child-type t i) "''."))))))))
+		   "An argument of type \x10"
+                   (tree-child-type t i) "\x11."))))))))
 
 (tm-generate (focus-doc-usage t)
   ($let* ((lab (tree-label t))
@@ -74,7 +75,7 @@
   ($let* ((lab (tree-label t))
           (l (focus-variants-of t)))
     ($para
-      "The " ($markup lab) " tag admits various "
+      "The " ($markup lab) " tag has several "
       ($tmdoc-link "main/editing/man-structured-variants"
         "structured variants")
       ": " ($markup (car l))
@@ -108,16 +109,16 @@
           (lab* (symbol-toggle-alternate lab)))
     ($para
       ($when (alternate-first? t)
-        "The " ($markup lab) " environment is ``folded'' "
-        "and admits an unfolded variant  " ($markup lab*) ". "
+        "The " ($markup lab) " environment is \x10folded\x11 "
+        "and has an unfolded variant  " ($markup lab*) ". "
         "You may unfold the environment using the keyboard shortcut "
         ($shortcut (alternate-toggle (focus-tree))) ", the menu entry "
         ($menu "Focus" "Folded") ", or by pressing the "
         ($tmdoc-icon "tm_alternate_first.xpm")
         " icon on the focus toolbar. ")
       ($when (alternate-second? t)
-        "The " ($markup lab) " environment is ``unfolded'' "
-        "and admits a folded variant " ($markup lab*) ". "
+        "The " ($markup lab) " environment is \x10unfolded\x11 "
+        "and has a folded variant " ($markup lab*) ". "
         "You may fold the environment using the keyboard shortcut "
         ($shortcut (alternate-toggle (focus-tree))) ", the menu entry "
         ($menu "Focus" (alternate-second-name t)) ", or by pressing the "
@@ -279,12 +280,12 @@
             ($inline ($shortcut (structured-insert-left)) ", "
                      ($menu "Focus" "Insert left") ", "
                      ($tmdoc-icon "tm_insert_left.xpm"))
-          "Insert a new argument on the left-hand side of the cursor.")
+          "Insert a new argument at the left-hand side of the cursor.")
         ($describe-item
             ($inline ($shortcut (structured-insert-right)) ", "
                      ($menu "Focus" "Insert right") ", "
                      ($tmdoc-icon "tm_insert_right.xpm"))
-          "Insert a new argument on the right-hand side of the cursor."))
+          "Insert a new argument at the right-hand side of the cursor."))
       ($when (structured-vertical? t)
         ($describe-item
             ($inline ($shortcut (structured-insert-up)) ", "
@@ -304,7 +305,7 @@
             ($inline ($shortcut (structured-remove-left)) ", "
                      ($menu "Focus" "Remove left") ", "
                      ($tmdoc-icon "tm_delete_left.xpm"))
-          "Remove the argument on the left-hand side of the cursor.")
+          "Remove the argument at the left-hand side of the cursor.")
         ($describe-item
             ($inline ($shortcut (structured-remove-right)) ", "
                      ($menu "Focus" "Remove right") ", "
@@ -359,8 +360,8 @@
 
 (tm-define (focus-doc t)
   ($tmdoc
-    ($tmdoc-title "Contextual help on the ``"
-                  (symbol->string (tree-label t)) "'' tag")
+    ($tmdoc-title "Contextual help on the \x10"
+                  (symbol->string (tree-label t)) "\x11 tag")
     ($when #t
       ($unfolded-documentation "Usage"
 	(focus-doc-usage t)))
@@ -403,7 +404,12 @@
 ;; Public interface
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-(tm-define (focus-help)
+(tm-define (old-focus-help)
   (lazy-initialize-force)
   (cursor-history-add (cursor-path))
   (open-auxiliary "Contextual help" (focus-doc (focus-tree))))
+
+(tm-define (focus-help)
+  (if (tree-is-buffer? (focus-tree))
+      (auto-load-help "Contextual help" "top-help")
+      (auto-load-help "Contextual help" "tag-help")))
