@@ -26,6 +26,7 @@
 (define-public widget-style-button 32)
 (define-public widget-style-centered 64)
 (define-public widget-style-bold 128)
+(define-public widget-style-verb 256)
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Control structures
@@ -136,6 +137,10 @@
   (:synopsis "Make a refreshable widget")
   `(cons* 'refreshable (lambda () ,kind) ($list ,@l)))
 
+(tm-define-macro ($cached kind valid? . l)
+  (:synopsis "Make a cached widget")
+  `(cons* 'cached (lambda () ,kind) (lambda () ,valid?) ($list ,@l)))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; General layout widgets
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -156,6 +161,14 @@
   (:synopsis "Vertical layout of widgets")
   `(cons* 'vlist ($list ,@l)))
 
+(tm-define-macro ($division name . l)
+  (:synopsis "Widget with CSS style name")
+  `(cons* 'division (lambda () ,name) ($list ,@l)))
+
+(tm-define-macro ($class name . l)
+  (:synopsis "Widget with CSS style name")
+  `(cons* 'class (lambda () ,name) ($list ,@l)))
+
 (tm-define-macro ($aligned . l)
   (:synopsis "Align two column table")
   `(cons* 'aligned ($list ,@l)))
@@ -344,6 +357,10 @@
   `(list 'filtered-choice (lambda (answer filter) ,cmd) (lambda () ,vals)
                            (lambda () ,val) (lambda () ,filterstr)))
 
+(tm-define-macro ($color-input cmd bg? proposals)
+  (:synopsis "Make color picker")
+  `(list 'color-input (lambda (answer) ,cmd) ,bg? (lambda () ,proposals)))
+
 (tm-define-macro ($tree-view cmd data roles)
   (:synopsis "Make a tree view of the data")
   `(list 'tree-view (lambda x (apply ,cmd (reverse x)))
