@@ -211,6 +211,9 @@
   "Pretty print the association list @l as a string."
   (string-recompose (map property-pair->string l) "/"))
 
+(define-public (raw-quote s)
+  (string-append (string-append "\"" s "\"")))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Some string-like functions on symbols
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -305,8 +308,8 @@
   (system-remove u))
 
 (define-public (url-autosave u suf)
-  (and (not (url-rooted-web? name))
-       (not (url-rooted-tmfs? name))
+  (and (not (url-rooted-web? u))
+       (not (url-rooted-tmfs? u))
        (url-glue u suf)))
 
 (define-public (url-wrap u)
@@ -318,6 +321,14 @@
       (set! u (url-delta base u))))
   (url->unix u))
 
+(define-public (first-in-path . l)
+  (cond ((null? l) #f)
+        ((url-exists-in-path? (car l)) (car l))
+        (else (apply first-in-path (cdr l)))))
+
+(define-public (python-command)
+  (first-in-path "python3" "python" "python2"))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Buffers
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
