@@ -19,26 +19,33 @@
   (define Assign-symbol
     (:type infix)
     (:penalty 3)
-    (:spacing default default)
-    "<assign>" "<plusassign>" "<minusassign>" "<astassign>" "<overassign>")
+    (:spacing wide wide)
+    "<assign>" "<backassign>"
+    "<plusassign>" "<minusassign>" "<astassign>" "<overassign>")
   
   (define Flux-symbol
     (:type infix)
-    (:spacing default default)
+    (:spacing wide wide)
     "<lflux>" "<gflux>")
 
   (define Models-symbol
-    (:type infix)
-    (:spacing default default)
+    (:type prefix-infix)
+    (:spacing default wide)
     "<models>"
-    "<vdash>" "<dashv>" "<vDash>" "<Dashv>"
-    "<Vdash>" "<dashV>" "<VDash>" "<DashV>"
-    "<Vvdash>" "<dashVv>" "<VvDash>" "<DashVv>"
-    "<longvdash>" "<longdashv>" "<longvDash>" "<longDashv>"
-    "<longVdash>" "<longdashV>" "<longVDash>" "<longDashV>"
-    "<longVvdash>" "<longdashVv>" "<longVvDash>" "<longDashVv>"
-    "<nvdash>" "<ndashv>" "<nvDash>" "<nDashv>"
-    "<nVdash>" "<ndashV>" "<nVDash>" "<nDashV>")
+    "<vdash>" "<vDash>" "<Vdash>" "<VDash>" "<Vvdash>" "<VvDash>"
+    "<longvdash>" "<longvDash>"
+    "<longVdash>" "<longVDash>"
+    "<longVvdash>" "<longVvDash>"
+    "<nvdash>" "<nvDash>" "<nVdash>" "<nVDash>" "<nVvdash>" "<nVvDash>")
+
+  (define Modeled-symbol
+    (:type infix)
+    (:spacing default wide)
+    "<dashv>" "<Dashv>" "<dashV>" "<DashV>" "<dashVv>" "<DashVv>"
+    "<longdashv>" "<longDashv>"
+    "<longdashV>" "<longDashV>"
+    "<longdashVv>" "<longDashVv>"
+    "<ndashv>" "<nDashv>" "<ndashV>" "<nDashV>" "<ndashVv>" "<nDashVv>")
 
   (define Quantifier-symbol
     (:type prefix)
@@ -47,16 +54,17 @@
   (define Imply-nolim-symbol
     (:type infix)
     (:penalty 10)
-    (:spacing default default)
+    (:spacing wide wide)
     "<implies>" "<equivalent>" "<Leftarrow>" "<Rightarrow>" "<Leftrightarrow>"
     "<Longleftarrow>" "<Longrightarrow>" "<Longleftrightarrow>"
-    "<Lleftarrow>" "<Rrightarrow>"
+    "<Llongleftarrow>" "<Llongrightarrow>" "<Llongleftrightarrow>"
+    "<Lleftarrow>" "<Rrightarrow>" "<LRleftrightarrow>"
     "<nLeftarrow>" "<nRightarrow>" "<nLeftrightarrow>")
 
   (define Imply-lim-symbol
     (:type infix)
     (:penalty 10)
-    (:spacing default default)
+    (:spacing wide wide)
     (:limits always)
     "<Leftarrowlim>" "<Rightarrowlim>" "<Leftrightarrowlim>"
     "<Longleftarrowlim>" "<Longrightarrowlim>" "<Longleftrightarrowlim>")
@@ -67,13 +75,13 @@
   (define Or-symbol
     (:type infix)
     (:penalty 10)
-    (:spacing default default)
+    (:spacing wide wide)
     "<vee>" "<curlyvee>" "<veebar>" "<obar>" "<boxbar>")
 
   (define And-symbol
     (:type infix)
     (:penalty 10)
-    (:spacing default default)
+    (:spacing wide wide)
     "<wedge>" "<curlywedge>" "<barwedge>" "<doublebarwedge>")
 
   (define Not-symbol
@@ -84,14 +92,17 @@
   (define Relation-nolim-symbol
     (:type infix)
     (:penalty 20)
-    (:spacing default default)
+    (:spacing wide wide)
 
-    "=" "<ne>" "<neq>" "<longequal>" "<less>" "<gtr>" "<le>" "<leq>"
-    "<prec>" "<preceq>" "<ll>" "<lleq>" "<subset>" "<subseteq>"
-    "<sqsubset>" "<sqsubseteq>" "<in>" "<ni>" "<of>"
-    "<ge>" "<geq>" "<succ>" "<succeq>"
-    "<gg>" "<ggeq>" "<supset>" "<supseteq>" "<sqsupset>" "<sqsupseteq>"
+    "=" "<ne>" "<neq>" "<longequal>" "<longequiv>"
+    "<less>" "<gtr>" "<le>" "<leq>"
+    "<prec>" "<preceq>" "<preceqq>" "<ll>" "<lleq>" "<subset>" "<subseteq>"
+    "<sqsubset>" "<sqsubseteq>" "<sqsubseteqq>" "<in>" "<ni>" "<of>"
+    "<ge>" "<geq>" "<succ>" "<succeq>" "<succeqq>"
+    "<gg>" "<ggeq>" "<supset>" "<supseteq>"
+    "<sqsupset>" "<sqsupseteq>" "<sqsupseteqq>"
     "<equiv>" "<nequiv>" "<sim>" "<simeq>" "<asymp>" "<approx>" "<cong>"
+    "<triplesim>" "<ntriplesim>"
     "<subsetsim>" "<supsetsim>" "<doteq>" "<propto>" "<varpropto>"
     "<perp>" "<bowtie>" "<Join>" "<smile>" "<frown>" "<signchange>"
     "<parallel>" "<shortparallel>" "<nparallel>" "<nshortparallel>"
@@ -101,50 +112,74 @@
     "<Bumpeq>" "<bumpeq>" "<circeq>" "<triangleq>"
     "<curlyeqprec>" "<curlyeqsucc>" "<Doteq>" "<doteqdot>" "<eqcirc>"
     "<eqslantgtr>" "<eqslantless>" "<fallingdotseq>" "<geqq>" "<geqslant>"
-    "<ggg>" "<gggtr>" "<gnapprox>" "<gneq>" "<gneqq>" "<gnsim>" "<gtrapprox>"
-    "<gtrdot>" "<gtreqdot>" "<gtreqless>" "<gtreqqless>" "<gtrless>"
+    "<ggg>" "<gggtr>" "<ngtrapprox>" "<gnapprox>" "<gneq>" "<gneqq>"
+    "<ngtrsim>" "<gnsim>" "<gtrapprox>"
+    "<gtrdot>" "<gtreqdot>" "<dotgtr>" "<dotgeq>" "<dotgeqslant>"
+    "<gtreqless>" "<gtreqqless>" "<gtrless>"
     "<gtrsim>" "<gvertneqq>" "<leqq>" "<leqslant>" "<lessapprox>"
-    "<lessdot>" "<lesseqdot>" "<lesseqgtr>" "<lesseqqgtr>" "<lessgtr>"
-    "<lesssim>" "<lll>" "<llless>" "<lnapprox>" "<lneq>" "<lneqq>"
-    "<lnsim>" "<lvertneqq>" "<napprox>" "<ngeq>" "<ngeqq>" "<ngeqslant>"
-    "<ngtr>" "<nleq>" "<nleqq>" "<nleqslant>" "<nless>" "<nprec>" "<npreceq>"
-    "<nsim>" "<nsimeq>""<ncong>" "<nasymp>" "<nsubset>" "<nsupset>"
-    "<nsqsubset>" "<nsqsupset>" "<nsqsubseteq>" "<nsqsupseteq>"
-    "<nsubseteq>" "<nsucc>" "<nsucceq>"
+    "<lessdot>" "<lesseqdot>" "<leqdot>" "<leqslantdot>"
+    "<lesseqgtr>" "<lesseqqgtr>" "<lessgtr>"
+    "<lesssim>" "<lll>" "<llless>" "<nlessapprox>" "<lnapprox>"
+    "<lneq>" "<lneqq>" "<nlesssim>" "<lnsim>"
+    "<lvertneqq>" "<napprox>" "<ngeq>" "<ngeqq>" "<ngeqslant>"
+    "<ngtr>" "<nleq>" "<nleqq>" "<nleqslant>" "<nless>"
+    "<nprec>" "<npreceq>" "<precneq>" "<npreceqq>"
+    "<nsim>" "<nsimeq>""<ncong>" "<napproxeq>"
+    "<nasymp>" "<nsubset>" "<nsupset>" "<nsqsubset>" "<nsqsupset>"
+    "<nsqsubseteq>" "<sqsubsetneq>" "<varsqsubsetneq>"
+    "<nsqsupseteq>" "<sqsupsetneq>" "<varsqsupsetneq>"
+    "<nsqsubseteqq>" "<sqsubsetneqq>" "<varsqsubsetneqq>"
+    "<nsqsupseteqq>" "<sqsupsetneqq>" "<varsqsupsetneqq>"
+    "<nsubseteq>" "<nsucc>" "<nsucceq>" "<succneq>" "<nsucceqq>"
     "<nsupseteq>" "<nsupseteqq>" "<precapprox>" "<preccurlyeq>"
-    "<npreccurlyeq>" "<precnapprox>" "<precneqq>"
-    "<precsim>" "<precnsim>" "<risingdoteq>" "<Subset>"
-    "<subseteqq>" "<subsetneq>" "<subsetneqq>" "<succapprox>"
-    "<succcurlyeq>" "<nsucccurlyeq>" "<succnapprox>" "<succneqq>"
-    "<succsim>" "<succnsim>" "<Supset>" "<supseteqq>"
-    "<supsetneq>" "<supsetneqq>"
+    "<npreccurlyeq>" "<nprecapprox>" "<precnapprox>"
+    "<precneqq>" "<precvertneqq>"
+    "<precsim>" "<nprecsim>" "<precnsim>" "<risingdoteq>" "<Subset>"
+    "<subseteqq>" "<subsetneq>"
+    "<nsubseteqq>" "<subsetneqq>" "<succapprox>"
+    "<succcurlyeq>" "<nsucccurlyeq>" "<nsuccapprox>" "<succnapprox>"
+    "<succneqq>" "<succvertneqq>"
+    "<succsim>" "<nsuccsim>" "<succnsim>" "<Supset>" "<supseteqq>"
+    "<nsupsetneqq>" "<supsetneq>" "<supsetneqq>"
     "<thickapprox>" "<thicksim>" "<varsubsetneq>" "<varsubsetneqq>"
     "<varsupsetneq>" "<varsupsetneqq>" "<llleq>" "<gggeq>"
     "<subsetplus>" "<supsetplus>"
+    "<nll>" "<nlleq>" "<nlll>" "<nllleq>"
+    "<ngg>" "<nggeq>" "<nggg>" "<ngggeq>"
 
     "<vartriangleleft>" "<vartriangleright>"
     "<triangleleft>" "<triangleright>"
-    "<trianglelefteq>" "<trianglerighteq>" "<trianglelefteqslant>"
-    "<trianglerighteqslant>" "<blacktriangleleft>" "<blacktriangleright>"
+    "<trianglelefteq>" "<trianglerighteq>"
+    "<trianglelefteqslant>" "<trianglerighteqslant>"
+    "<blacktriangleleft>" "<blacktriangleright>"
+    "<blacktrianglelefteq>" "<blacktrianglerighteq>"
+    "<blacktrianglelefteqslant>" "<blacktrianglerighteqslant>"
     "<ntriangleleft>" "<ntriangleright>"
     "<ntrianglelefteq>" "<ntrianglerighteq>"
     "<ntrianglelefteqslant>" "<ntrianglerighteqslant>"
+    "<nblacktriangleleft>" "<nblacktriangleright>"
+    "<nblacktrianglelefteq>" "<nblacktrianglerighteq>"
+    "<nblacktrianglelefteqslant>" "<nblacktrianglerighteqslant>"
 
     "<precprec>" "<precpreceq>" "<precprecprec>" "<precprecpreceq>"
     "<succsucc>" "<succsucceq>" "<succsuccsucc>" "<succsuccsucceq>"
     "<nprecprec>" "<nprecpreceq>" "<nprecprecprec>" "<nprecprecpreceq>"
     "<nsuccsucc>" "<nsuccsucceq>" "<nsuccsuccsucc>" "<nsuccsuccsucceq>"
     "<asympasymp>" "<nasympasymp>" "<simsim>" "<nsimsim>" "<nin>" "<nni>"
-    "<notin>" "<notni>" "<precdot>" "<preceqdot>" "<dotsucc>" "<dotsucceq>"
+    "<notin>" "<notni>"
+    "<precdot>" "<preceqdot>" "<preccurlyeqdot>"
+    "<dotsucc>" "<dotsucceq>" "<dotsucccurlyeq>"
 
-    "<because>" "<between>" "<therefore>")
+    "<because>" "<between>" "<therefore>" "<lebar>" "<gebar>"
+    "<leangle>" "<geangle>" "<leqangle>" "<geqangle>"
+    "<legeangle>" "<geleangle>")
 
   (define Relation-lim-symbol
     (:type infix)
     (:penalty 20)
-    (:spacing default default)
+    (:spacing wide wide)
     (:limits always)
-    "<equallim>" "<longequallim>")
+    "<equallim>" "<longequallim>" "<longequivlim>")
 
   (define Relation-symbol
     Relation-nolim-symbol Relation-lim-symbol)
@@ -161,7 +196,8 @@
     "<longmapsto>" "<longmapsfrom>"
     "<longhookleftarrow>" "<longhookrightarrow>" "<leftharpoonup>"
     "<leftharpoondown>" "<rightleftharpoons>" "<rightharpoonup>"
-    "<rightharpoondown>" "<leadsto>" "<nleadsto>"
+    "<rightharpoondown>" "<longleftharpoonup>" "<longleftharpoondown>"
+    "<longrightharpoonup>" "<longrightharpoondown>" "<leadsto>" "<nleadsto>"
     "<nearrow>" "<searrow>" "<swarrow>" "<nwarrow>"
     "<longtwoheadleftarrow>" "<longtwoheadrightarrow>"
     "<leftprec>" "<leftpreceq>" "<succright>" "<succeqright>"
@@ -169,15 +205,25 @@
     "<circlearrowleft>" "<circlearrowdown>"
     "<curvearrowleft>" "<curvearrowright>"
     "<downdownarrows>" "<downharpoonleft>" "<downharpoonright>"
+    "<longdownharpoonleft>" "<longdownharpoonright>"
     "<leftarrowtail>" "<leftleftarrows>" "<leftrightarrows>"
+    "<longleftleftarrows>" "<longleftrightarrows>"
+    "<longthreeleftarrows>" "<longthreerightarrows>"
+    "<longfourleftarrows>" "<longfourrightarrows>"
     "<leftrightharpoons>" "<rightleftharpoons>"
-    "<looparrowleft>" "<looparrowright>" "<Lsh>" "<multimap>"
+    "<longleftrightharpoons>" "<longrightleftharpoons>"
+    "<looparrowleft>" "<looparrowright>" "<Lsh>"
+    "<multimap>" "<mapmulti>" "<longmultimap>" "<longmapmulti>"
     "<nleftarrow>" "<nleftrightarrow>" "<nrightarrow>" "<restriction>"
     "<rightarrowtail>" "<rightleftarrows>" "<rightrightarrows>"
+    "<longrightleftarrows>" "<longrightrightarrows>"
     "<leftsquigarrow>" "<rightsquigarrow>" "<leftrightsquigarrow>"
     "<Rsh>" "<twoheadleftarrow>" "<twoheadrightarrow>"
-    "<upharpoonleft>" "<upharpoonright>" "<upuparrows>"
-    "<leftrightmap>" "<pointer>")
+    "<upharpoonleft>" "<upharpoonright>"
+    "<longupharpoonleft>" "<longupharpoonright>"
+    "<upuparrows>" "<leftrightmap>" "<pointer>"
+    "<threeleftarrows>" "<threerightarrows>"
+    "<fourleftarrows>" "<fourrightarrows>")
   
   (define Arrow-lim-symbol
     (:type infix)
@@ -187,7 +233,9 @@
     "<leftarrowlim>" "<rightarrowlim>" "<leftrightarrowlim>"
     "<longleftarrowlim>" "<longrightarrowlim>" "<longleftrightarrowlim>"
     "<mapstolim>" "<longmapstolim>"
-    "<leftsquigarrowlim>" "<rightsquigarrowlim>" "<leftrightsquigarrowlim>")
+    "<leftsquigarrowlim>" "<rightsquigarrowlim>" "<leftrightsquigarrowlim>"
+    "<longleftleftarrowslim>" "<longleftrightarrowslim>"
+    "<longrightleftarrowslim>" "<longrightrightarrowslim>")
 
   (define Arrow-symbol
     Arrow-nolim-symbol Arrow-lim-symbol)
@@ -208,17 +256,17 @@
     (:type infix)
     (:penalty 30)
     (:spacing default default)
-    "<setminus>" "<smallsetminus>")
+    "<setminus>" "<smallsetminus>" "<bslash>")
 
   (define Plus-visible-symbol
-    (:type infix)
+    (:type prefix-infix)
     (:penalty 30)
     (:spacing default default)
     "+" "<amalg>" "<oplus>" "<boxplus>"
-    "<dotplus>" "<dotamalg>" "<dotoplus>")
+    "<dotplus>" "<dotamalg>" "<dotoplus>" "<pplus>")
 
   (define Plus-invisible-symbol
-    (:type infix)
+    (:type prefix-infix)
     (:penalty invalid)
     (:spacing none default)
     "<noplus>")
@@ -233,7 +281,7 @@
     "<upl>")
 
   (define Minus-symbol
-    (:type infix)
+    (:type prefix-infix)
     (:penalty 30)
     (:spacing default default)
     "-" "<pm>" "<mp>" "<minus>" "<longminus>"
@@ -252,16 +300,18 @@
     (:spacing default default)
     "<cdot>" "<times>" "<otimes>" "<product>"
     "<circ>" "<bullet>" "<odot>" "<boxdot>" "<boxtimes>" "<boxcircle>"
-    "<dottimes>" "<dototimes>" "<ltimes>" "<rtimes>" "<atimes>" "<btimes>"
+    "<dottimes>" "<dototimes>"
+    "<ltimes>" "<rtimes>" "<btimes>" "<ttimes>"
     "<exterior>" "<join>"
     "<ast>" "<star>" "<oast>" "<boxast>" "<dotast>"
     "<circledast>" "<circledcirc>" "<varocircle>" "<boxbox>"
-    "<leftthreetimes>" "<rightthreetimes>")
+    "<leftthreetimes>" "<rightthreetimes>"
+    "<lefttimesthree>" "<righttimesthree>")
 
   (define Times-invisible-symbol
     (:type infix)
     (:penalty invalid)
-    (:spacing half half)
+    (:spacing multiply multiply)
     "*")
 
   (define Times-symbol
@@ -271,13 +321,14 @@
     (:type infix)
     (:penalty 40)
     (:spacing default default)
-    "<over>" "<div>" "<oover>" "<divideontimes>" "<oslash>" "<boxslash>")
+    "<over>" "<div>" "<oover>" "<divideontimes>"
+    "<oslash>" "<boxslash>" "<dslash>")
 
   (define Over-condensed-symbol
     (:type infix)
     (:penalty 40)
     (:spacing half half)
-    "/")
+    "/" "\\")
 
   (define Over-symbol
     Over-regular-symbol Over-condensed-symbol)
@@ -327,14 +378,14 @@
 
   (define Big-nolim-symbol
     (:type prefix)
-    (:penalty panic)
+    (:penalty invalid)
     (:spacing none big)
     "<big-int>" "<big-iint>" "<big-iiint>" "<big-iiiint>" "<big-idotsint>"
     "<big-oint>" "<big-oiint>" "<big-oiiint>")
 
   (define Big-lim-symbol
     (:type prefix)
-    (:penalty panic)
+    (:penalty invalid)
     (:spacing none big)
     (:limits display)
     "<big-sum>" "<big-prod>" "<big-amalg>"
@@ -358,12 +409,13 @@
 
   (define Other-postfix-symbol
     (:type postfix)
-    (:penalty panic)
-    "!" "%" "<permil>" "<postup>" "<postdown>")
+    (:penalty invalid)
+    "!" "%" "<permil>"
+    "<postup>" "<postdown>" "<postupdown>" "<postmapsup>" "<postmapsdown>")
 
   (define Prime-symbol
     (:type symbol)
-    (:penalty panic)
+    (:penalty invalid)
     "'" "`" "<dag>" "<ddag>" "<asterisk>" "<star>" "<kreuz>")
 
   (define Ponctuation-visible-symbol
@@ -393,9 +445,19 @@
     "<left-lfloor>" "<left-lceil>" "<left-rfloor>" "<left-rceil>"
     "<left-langle>" "<left-rangle>")
   
-  (define Middle-symbol
+  (define Middle-bracket-symbol
     (:type middle-bracket)
+    (:spacing middle middle)
     "|" "<||>" "<nobracket>" "<mid-|>" "<mid-||>" "<mid-.>")
+  
+  (define Middle-separator-symbol
+    (:type middle-bracket)
+    (:penalty 0)
+    (:spacing default default)
+    "<suchthat>" "<barsuchthat>")
+
+  (define Middle-symbol
+    Middle-bracket-symbol Middle-separator-symbol)
 
   (define Close-symbol
     (:type closing-bracket)
@@ -427,11 +489,13 @@
   (define Letter-symbol
     (:type symbol)
 
-    "<mathe>" "<mathi>" "<mathpi>"
+    "<mathe>" "<mathi>" "<mathlambda>" "<mathpi>"
     "<matheuler>" "<mathcatalan>" "<mathGamma>"
     "<aleph>" "<beth>" "<gimel>" "<daleth>"
-    "<hbar>" "<hslash>" "<imath>" "<jmath>"
-    "<ell>" "<b-ell>" "<wp>" "<digamma>"
+    "<hbar>" "<hslash>" "<wp>" "<digamma>"
+    "<imath>" "<b-imath>" "<jmath>" "<b-jmath>" "<ell>" "<b-ell>"
+    "<cal-imath>" "<b-cal-imath>" "<cal-jmath>" "<b-cal-jmath>"
+    "<frak-imath>" "<frak-jmath>" "<bbb-imath>" "<bbb-jmath>"
 
     "<alpha>" "<beta>" "<gamma>" "<delta>" "<epsilon>"
     "<varepsilon>" "<zeta>" "<eta>" "<theta>" "<vartheta>"
@@ -445,7 +509,20 @@
     "<Eta>" "<Theta>" "<Iota>" "<Kappa>" "<Lambda>" "<Mu>" "<Nu>"
     "<Xi>" "<Omicron>" "<Pi>" "<Rho>" "<Sigma>" "<Tau>"
     "<Upsilon>" "<Phi>" "<Psi>" "<Chi>" "<Omega>"
-    "<Backepsilon>" "<Mho>"
+    "<Backepsilon>" "<Backsigma>" "<Mho>"
+
+    "<b-0>" "<b-1>" "<b-2>" "<b-3>" "<b-4>"
+    "<b-5>" "<b-6>" "<b-7>" "<b-8>" "<b-9>"
+
+    "<b-a>" "<b-b>" "<b-c>" "<b-d>" "<b-e>" "<b-f>" "<b-g>"
+    "<b-h>" "<b-i>" "<b-j>" "<b-k>" "<b-l>" "<b-m>" "<b-n>"
+    "<b-o>" "<b-p>" "<b-q>" "<b-r>" "<b-s>" "<b-t>" "<b-u>"
+    "<b-v>" "<b-w>" "<b-x>" "<b-y>" "<b-z>"
+
+    "<b-A>" "<b-B>" "<b-C>" "<b-D>" "<b-E>" "<b-F>" "<b-G>"
+    "<b-H>" "<b-I>" "<b-J>" "<b-K>" "<b-L>" "<b-M>" "<b-N>"
+    "<b-O>" "<b-P>" "<b-Q>" "<b-R>" "<b-S>" "<b-T>" "<b-U>"
+    "<b-V>" "<b-W>" "<b-X>" "<b-Y>" "<b-Z>"
 
     "<b-alpha>" "<b-beta>" "<b-gamma>" "<b-delta>" "<b-epsilon>"
     "<b-varepsilon>" "<b-zeta>" "<b-eta>" "<b-theta>" "<b-vartheta>"
@@ -460,7 +537,18 @@
     "<b-Lambda>" "<b-Mu>" "<b-Nu>" "<b-Xi>" "<b-Omicron>"
     "<b-Pi>" "<b-Rho>" "<b-Sigma>" "<b-Tau>" "<b-Upsilon>"
     "<b-Phi>" "<b-Psi>" "<b-Chi>" "<b-Omega>"
-    "<b-Backepsilon>" "<b-Mho>"
+    "<b-Backepsilon>" "<b-Backsigma>" "<b-Mho>"
+
+    "<up-a>" "<up-b>" "<up-c>" "<up-d>" "<up-e>" "<up-f>" "<up-g>"
+    "<up-h>" "<up-i>" "<up-j>" "<up-k>" "<up-l>" "<up-m>" "<up-n>"
+    "<up-o>" "<up-p>" "<up-q>" "<up-r>" "<up-s>" "<up-t>" "<up-u>"
+    "<up-v>" "<up-w>" "<up-x>" "<up-y>" "<up-z>"
+    "<up-imath>" "<up-jmath>" "<up-ell>"
+
+    "<up-A>" "<up-B>" "<up-C>" "<up-D>" "<up-E>" "<up-F>" "<up-G>"
+    "<up-H>" "<up-I>" "<up-J>" "<up-K>" "<up-L>" "<up-M>" "<up-N>"
+    "<up-O>" "<up-P>" "<up-Q>" "<up-R>" "<up-S>" "<up-T>" "<up-U>"
+    "<up-V>" "<up-W>" "<up-X>" "<up-Y>" "<up-Z>"
 
     "<up-alpha>" "<up-beta>" "<up-gamma>" "<up-delta>" "<up-epsilon>"
     "<up-varepsilon>" "<up-zeta>" "<up-eta>" "<up-theta>" "<up-vartheta>"
@@ -470,15 +558,12 @@
     "<up-phi>" "<up-varphi>" "<up-psi>" "<up-chi>" "<up-omega>"
     "<up-backepsilon>" "<up-mho>"
 
-    "<b-a>" "<b-b>" "<b-c>" "<b-d>" "<b-e>" "<b-f>" "<b-g>"
-    "<b-h>" "<b-i>" "<b-j>" "<b-k>" "<b-l>" "<b-m>" "<b-n>"
-    "<b-o>" "<b-p>" "<b-q>" "<b-r>" "<b-s>" "<b-t>" "<b-u>"
-    "<b-v>" "<b-w>" "<b-x>" "<b-y>" "<b-z>"
-
-    "<b-A>" "<b-B>" "<b-C>" "<b-D>" "<b-E>" "<b-F>" "<b-G>"
-    "<b-H>" "<b-I>" "<b-J>" "<b-K>" "<b-L>" "<b-M>" "<b-N>"
-    "<b-O>" "<b-P>" "<b-Q>" "<b-R>" "<b-S>" "<b-T>" "<b-U>"
-    "<b-V>" "<b-W>" "<b-X>" "<b-Y>" "<b-Z>"
+    "<up-Alpha>" "<up-Beta>" "<up-Gamma>" "<up-Delta>" "<up-Epsilon>"
+    "<up-Zeta>" "<up-Eta>" "<up-Theta>" "<up-Iota>" "<up-Kappa>"
+    "<up-Lambda>" "<up-Mu>" "<up-Nu>" "<up-Xi>" "<up-Omicron>"
+    "<up-Pi>" "<up-Rho>" "<up-Sigma>" "<up-Tau>" "<up-Upsilon>"
+    "<up-Phi>" "<up-Psi>" "<up-Chi>" "<up-Omega>"
+    "<up-Backepsilon>" "<up-Mho>"
 
     "<b-up-a>" "<b-up-b>" "<b-up-c>" "<b-up-d>" "<b-up-e>" "<b-up-f>"
     "<b-up-g>" "<b-up-h>" "<b-up-i>" "<b-up-j>" "<b-up-k>" "<b-up-l>"
@@ -492,8 +577,22 @@
     "<b-up-S>" "<b-up-T>" "<b-up-U>" "<b-up-V>" "<b-up-W>" "<b-up-X>"
     "<b-up-Y>" "<b-up-Z>"
 
-    "<b-0>" "<b-1>" "<b-2>" "<b-3>" "<b-4>"
-    "<b-5>" "<b-6>" "<b-7>" "<b-8>" "<b-9>"
+    "<b-up-alpha>" "<b-up-beta>" "<b-up-gamma>" "<b-up-delta>"
+    "<b-up-epsilon>" "<b-up-varepsilon>" "<b-up-zeta>" "<b-up-eta>"
+    "<b-up-theta>" "<b-up-vartheta>" "<b-up-iota>" "<b-up-kappa>"
+    "<b-up-varkappa>" "<b-up-lambda>" "<b-up-mu>" "<b-up-nu>"
+    "<b-up-xi>" "<b-up-omicron>" "<b-up-pi>" "<b-up-varpi>" "<b-up-rho>"
+    "<b-up-varrho>" "<b-up-sigma>" "<b-up-varsigma>" "<b-up-tau>"
+    "<b-up-upsilon>" "<b-up-phi>" "<b-up-varphi>" "<b-up-psi>"
+    "<b-up-chi>" "<b-up-omega>" "<b-up-backepsilon>" "<b-up-mho>"
+
+    "<b-up-Alpha>" "<b-up-Beta>" "<b-up-Gamma>" "<b-up-Delta>"
+    "<b-up-Epsilon>" "<b-up-Zeta>" "<b-up-Eta>" "<b-up-Theta>"
+    "<b-up-Iota>" "<b-up-Kappa>" "<b-up-Lambda>" "<b-up-Mu>"
+    "<b-up-Nu>" "<b-up-Xi>" "<b-up-Omicron>" "<b-up-Pi>"
+    "<b-up-Rho>" "<b-up-Sigma>" "<b-up-Tau>" "<b-up-Upsilon>"
+    "<b-up-Phi>" "<b-up-Psi>" "<b-up-Chi>" "<b-up-Omega>"
+    "<b-up-Backepsilon>" "<b-up-Mho>"
     
     "<cal-a>" "<cal-b>" "<cal-c>" "<cal-d>" "<cal-e>" "<cal-f>" "<cal-g>"
     "<cal-h>" "<cal-i>" "<cal-j>" "<cal-k>" "<cal-l>" "<cal-m>" "<cal-n>"
@@ -551,7 +650,7 @@
     "<updownarrow>" "<Updownarrow>" "<mapsup>" "<mapsdown>"
     "<hookuparrow>" "<hookdownarrow>"
     "<upsquigarrow>" "<downsquigarrow>" "<updownsquigarrow>"
-    "<upequal>" "<downequal>"
+    "<upminus>" "<downminus>" "<upequal>" "<downequal>"
     "<longuparrow>" "<Longuparrow>"
     "<longdownarrow>" "<Longdownarrow>" "<longupdownarrow>" "<Longupdownarrow>"
     "<longmapsup>" "<longmapsdown>" "<longhookuparrow>" "<longhookdownarrow>"
@@ -560,15 +659,16 @@
     "<prime>" "<emptyset>"
     "<surd>" "<top>" "<bot>" "<angle>"
     "<flat>" "<natural>" "<sharp>" "<backslash>"
-    "<infty>" "<infty>" "<Box>" "<Diamont>"
+    "<infty>" "<infty>" "<Box>" "<Diamont>" "<oempty>" "<boxempty>"
     "<triangle>" "<clubsuit>" "<diamondsuit>" "<heartsuit>"
-    "<spadesuit>" "<diamond>" "<box>" "<bullet>"
+    "<spadesuit>" "<diamond>" "<box>" "<smallbox>" "<bullet>"
     "<eigthnote>" "<quarternote>" "<halfnote>" "<fullnote>" "<twonotes>"
     "<sun>" "<leftmoon>" "<rightmoon>" "<earth>" "<male>" "<female>"
     "<kreuz>" "<recorder>" "<phone>" "<checked>" "<bell>"
 
     "<backprime>" "<bigstar>" "<blacklozenge>"
-    "<blacksquare>" "<blacktriangle>" "<blacktriangledown>"
+    "<blacksquare>" "<blacktriangle>"
+    "<blacktriangleup>" "<blacktriangledown>"
     "<centerdot>" "<checkmark>"
     "<intercal>" "<llcorner>"
     "<lozenge>" "<lrcorner>" "<maltese>" "<measuredangle>"
@@ -618,8 +718,8 @@
   ;;  (:penalty invalid)
   ;;  (:spacing none default)
   ;;  "arccos" "arcsin" "arctan" "cos" "cosh" "cot" "coth" "csc"
-  ;;  "deg" "det" "dim" "exp" "gcd" "hom" "ker" "Pr"
-  ;;  "lg" "ln" "log" "sec" "sin" "sinh" "tan" "tanh")
+  ;;  "deg" "det" "dim" "exp" "hom" "ker" "lg" "ln" "log"
+  ;;  "Pr" "sec" "sin" "sinh" "tan" "tanh")
 
   (define Unary-operator-symbol
     Unary-operator-glyph-symbol
@@ -636,7 +736,8 @@
     (:penalty invalid)
     (:spacing none default)
     (:limits display)
-    "inf" "lim" "liminf" "limsup" "max" "min" "sup")
+    "gcd" "gcrd" "inf" "lclm" "lcm" "lim"
+    "liminf" "limsup" "max" "min" "statlim" "sup")
 
   (define Prefix-symbol
     Not-symbol
@@ -651,6 +752,7 @@
   (define Infix-symbol
     Assign-symbol
     Models-symbol
+    Modeled-symbol
     Imply-symbol
     Or-symbol
     And-symbol
@@ -669,4 +771,12 @@
     :<frac :<sqrt :<wide :<table :<row
     :<around :<around* :<big-around :<left :<mid :<right :<big
     :<lsub :<lsup :<rsub :<rsup :<lprime :<rprime
-    :<Prefix :<Postfix))
+    :<Prefix :<Postfix)
+
+  (attach-macro
+    ("<ldots>" low-dots)
+    ("<cdots>" center-dots)
+    ("<hdots>" high-dots)
+    ("<vdots>" vertical-dots)
+    ("<ddots>" diagonal-dots)
+    ("<udots>" upward-dots)))
