@@ -21,30 +21,36 @@
 
 (menu-bind insert-table-menu
   (if (and (style-has? "std-dtd") (in-text?) (style-has? "env-float-dtd"))
-      ("Small table" (begin
-                       (insert-go-to '(small-table "" "") '(0 0))
-                       (make 'tabular)))
-      ("Big table"   (begin
-                       (insert-go-to '(big-table "" "") '(0 0))
-                       (make 'tabular)))
-      ---)
+      (when (not (selection-active-non-small?))
+        ("Small table"
+         (wrap-selection-small
+           (insert-go-to '(small-table "" "") '(0 0))
+           (make 'tabular)))
+        ("Big table"
+         (wrap-selection-small
+           (insert-go-to '(big-table "" (document "")) '(0 0))
+           (make 'tabular)))
+        ---))
   (if (and (style-has? "calc-dtd") (calc-ready?))
       (link calc-table-menu)
       ---)
   (if (not (in-math?))
       ("Wide tabular" (make 'wide-tabular)))
-  ("Plain tabular" (make 'tabular))
-  ("Centered tabular" (make 'tabular*))
+  (when (not (selection-active-non-small?))
+    ("Plain tabular" (make 'tabular))
+    ("Centered tabular" (make 'tabular*)))
   (if (not (in-math?))
       ("Wide block" (make 'wide-block)))
-  ("Plain block" (make 'block))
-  ("Centered block" (make 'block*))
-  (if (and (style-has? "std-dtd") (in-math?))
-      ---
-      ("Matrix" (make 'matrix))
-      ("Determinant" (make 'det))
-      ("Choice" (make 'choice))
-      ("Stack" (make 'stack))))
+  (when (not (selection-active-non-small?))
+    ("Plain block" (make 'block))
+    ("Centered block" (make 'block*)))
+  (when (not (selection-active-non-small?))
+    (if (and (style-has? "std-dtd") (in-math?))
+        ---
+        ("Matrix" (make 'matrix))
+        ("Determinant" (make 'det))
+        ("Choice" (make 'choice))
+        ("Stack" (make 'stack)))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Submenus of the Table menu
@@ -110,7 +116,7 @@
 (menu-bind table-special-menu
   ("Table breaking" (toggle-table-hyphen))
   ;;("Deactivate" (table-deactivate))
-  ("Create table macro" (create-table-macro "")))
+  ("Create table macro" (create-table-macro "" :global)))
 
 (menu-bind cell-mode-menu
   ("Cells" (set-cell-mode "cell"))
@@ -171,48 +177,63 @@
   ("Vertical" (interactive cell-set-row-span)))
 
 (menu-bind cell-border-icons-menu
-  ((icon "tm_border_none.xpm")
-   (cell-set-borders "0ln" "0ln" "0ln" "0ln" #f #f #f #f))
-  ((icon "tm_border_l.xpm")
-   (cell-set-borders "0ln" "0ln" "1ln" "0ln" #f #f #f #f))
-  ((icon "tm_border_r.xpm")
-   (cell-set-borders "0ln" "0ln" "0ln" "1ln" #f #f #f #f))
-  ((icon "tm_border_lr.xpm")
-   (cell-set-borders "0ln" "0ln" "1ln" "1ln" #f #f #f #f))
-  ((icon "tm_border_t.xpm")
-   (cell-set-borders "1ln" "0ln" "0ln" "0ln" #f #f #f #f))
-  ((icon "tm_border_lt.xpm")
-   (cell-set-borders "1ln" "0ln" "1ln" "0ln" #f #f #f #f))
-  ((icon "tm_border_rt.xpm")
-   (cell-set-borders "1ln" "0ln" "0ln" "1ln" #f #f #f #f))
-  ((icon "tm_border_lrt.xpm")
-   (cell-set-borders "1ln" "0ln" "1ln" "1ln" #f #f #f #f))
-  ((icon "tm_border_b.xpm")
-   (cell-set-borders "0ln" "1ln" "0ln" "0ln" #f #f #f #f))
-  ((icon "tm_border_lb.xpm")
-   (cell-set-borders "0ln" "1ln" "1ln" "0ln" #f #f #f #f))
-  ((icon "tm_border_rb.xpm")
-   (cell-set-borders "0ln" "1ln" "0ln" "1ln" #f #f #f #f))
-  ((icon "tm_border_lrb.xpm")
-   (cell-set-borders "0ln" "1ln" "1ln" "1ln" #f #f #f #f))
-  ((icon "tm_border_tb.xpm")
-   (cell-set-borders "1ln" "1ln" "0ln" "0ln" #f #f #f #f))
-  ((icon "tm_border_ltb.xpm")
-   (cell-set-borders "1ln" "1ln" "1ln" "0ln" #f #f #f #f))
-  ((icon "tm_border_rtb.xpm")
-   (cell-set-borders "1ln" "1ln" "0ln" "1ln" #f #f #f #f))
-  ((icon "tm_border_lrtb.xpm")
-   (cell-set-borders "1ln" "1ln" "1ln" "1ln" #f #f #f #f)))
+  (with width (cell-get-pen-width)
+    ((icon "tm_border_none.xpm")
+     (cell-set-borders "0ln" "0ln" "0ln" "0ln" #f #f #f #f))
+    ((icon "tm_border_l.xpm")
+     (cell-set-borders "0ln" "0ln" width "0ln" #f #f #f #f))
+    ((icon "tm_border_r.xpm")
+     (cell-set-borders "0ln" "0ln" "0ln" width #f #f #f #f))
+    ((icon "tm_border_lr.xpm")
+     (cell-set-borders "0ln" "0ln" width width #f #f #f #f))
+    ((icon "tm_border_t.xpm")
+     (cell-set-borders width "0ln" "0ln" "0ln" #f #f #f #f))
+    ((icon "tm_border_lt.xpm")
+     (cell-set-borders width "0ln" width "0ln" #f #f #f #f))
+    ((icon "tm_border_rt.xpm")
+     (cell-set-borders width "0ln" "0ln" width #f #f #f #f))
+    ((icon "tm_border_lrt.xpm")
+     (cell-set-borders width "0ln" width width #f #f #f #f))
+    ((icon "tm_border_b.xpm")
+     (cell-set-borders "0ln" width "0ln" "0ln" #f #f #f #f))
+    ((icon "tm_border_lb.xpm")
+     (cell-set-borders "0ln" width width "0ln" #f #f #f #f))
+    ((icon "tm_border_rb.xpm")
+     (cell-set-borders "0ln" width "0ln" width #f #f #f #f))
+    ((icon "tm_border_lrb.xpm")
+     (cell-set-borders "0ln" width width width #f #f #f #f))
+    ((icon "tm_border_tb.xpm")
+     (cell-set-borders width width "0ln" "0ln" #f #f #f #f))
+    ((icon "tm_border_ltb.xpm")
+     (cell-set-borders width width width "0ln" #f #f #f #f))
+    ((icon "tm_border_rtb.xpm")
+     (cell-set-borders width width "0ln" width #f #f #f #f))
+    ((icon "tm_border_lrtb.xpm")
+     (cell-set-borders width width width width #f #f #f #f))))
 
 (menu-bind cell-borders-icons-menu
-  ((icon "tm_both_none.xpm")
-   (cell-set-borders "0ln" "0ln" "0ln" "0ln" "0ln" "0ln" "0ln" "0ln"))
-  ((icon "tm_both_h.xpm")
-   (cell-set-borders "0ln" "0ln" "1ln" "1ln" "0ln" "0ln" "1ln" "1ln"))
-  ((icon "tm_both_v.xpm")
-   (cell-set-borders "1ln" "1ln" "0ln" "0ln" "1ln" "1ln" "0ln" "0ln"))
-  ((icon "tm_both_hv.xpm")
-   (cell-set-borders "1ln" "1ln" "1ln" "1ln" "1ln" "1ln" "1ln" "1ln")))
+  (with width (cell-get-pen-width)
+    ((icon "tm_both_none.xpm")
+     (cell-set-borders "0ln" "0ln" "0ln" "0ln" "0ln" "0ln" "0ln" "0ln"))
+    ((icon "tm_both_h.xpm")
+     (cell-set-borders "0ln" "0ln" width width "0ln" "0ln" width width))
+    ((icon "tm_both_v.xpm")
+     (cell-set-borders width width "0ln" "0ln" width width "0ln" "0ln"))
+    ((icon "tm_both_hv.xpm")
+     (cell-set-borders width width width width width width width width))))
+
+(menu-bind cell-pen-width-menu
+  ("0.5ln" (cell-set-pen-width "0.5ln"))
+  ("1ln" (cell-set-pen-width "1ln"))
+  ("2ln" (cell-set-pen-width "2ln"))
+  ---
+  ("Other" (interactive cell-set-pen-width)))
+
+(menu-bind cell-compact-pen-width-menu
+  ("0.5ln" (cell-set-pen-width "0.5ln"))
+  ("1ln" (cell-set-pen-width "1ln"))
+  ("2ln" (cell-set-pen-width "2ln"))
+  ("Other" (interactive cell-set-pen-width)))
 
 (menu-bind cell-border-menu
   ("All" (interactive cell-set-border))
@@ -246,6 +267,9 @@
   ---
   ("Palette" (interactive-background
               (lambda (col) (cell-set-background col)) '()))
+  ("Pattern" (open-pattern-selector cell-set-background "1cm"))
+  ("Gradient" (open-gradient-selector cell-set-background))
+  ("Picture" (open-background-picture-selector cell-set-background))
   ("Other" (interactive cell-set-background)))
 
 (menu-bind cell-wrapping-menu
@@ -305,6 +329,7 @@
   (when (and (== (get-cell-mode) "cell") (not (selection-active-any?)))
     (-> "Span" (link cell-span-menu)))
   (-> "Border" (link cell-alt-border-menu))
+  (-> "Pen width" (link cell-pen-width-menu))
   (-> "Padding" (link cell-padding-menu))
   (-> "Horizontal alignment" (link cell-halign-menu))
   (-> "Vertical alignment" (link cell-valign-menu))
@@ -332,7 +357,7 @@
 (tm-menu (standard-focus-menu t)
   (:require (table-markup-context? t))
   (dynamic (focus-tag-menu t))
-  (-> "Move" (dynamic (focus-move-menu t)))
+  (-> "Move::similar" (dynamic (focus-move-menu t)))
   (-> "Resize" (dynamic (focus-insert-menu t)))
   ---
   (group "Table")
@@ -343,8 +368,9 @@
   (if (== (get-cell-mode) "column") (group "Column"))
   (if (== (get-cell-mode) "table") (group "Cells"))
   (link cell-menu)
+  (dynamic (focus-hidden-menu t))
   (dynamic (focus-extra-menu t))
-  (dynamic (focus-hidden-menu t)))
+  (dynamic (focus-label-menu t)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Icons for manipulation of tables
@@ -578,6 +604,9 @@
           (group "Border")
           (link cell-alt-border-menu)
           ---
+          (group "Pen width")
+          (link cell-compact-pen-width-menu)
+          ---
           (group "Padding")
           (link cell-padding-menu)))
     (=> (balloon (icon (eval (cell-halign-icon))) "Modify cell alignment")
