@@ -36,8 +36,6 @@
   "Sigma" "Tau" "Upsilon" "Phi" "Chi" "Psi" "Omega"
   "grave" "acute" "check" "breve" "invbreve" "bar"
   "cedille"
-  "AA" "AE" "DH" "L" "NG" "O" "OE" "S" "SS" "TH"
-  "aa" "ae" "dh" "dj" "i" "j" "l" "ng" "o" "oe" "ss" "sz" "th"
 
   "ast" "asterisk"
   
@@ -163,14 +161,29 @@
   ("^o" "Insert " (emulate-keyboard "hat o"))
   ("^u" "Insert " (emulate-keyboard "hat u"))
   ("S" "Make " (emulate-keyboard "S-F5 p"))
-  ("aa" "Insert aa" (emulate-keyboard "abovering a"))
-  ("oe" "Insert oe" (emulate-keyboard "S-F5 o e"))
+  ("aa" "Insert " (insert ""))
   ("ae" "Insert ae" (emulate-keyboard "S-F5 a"))
+  ("dh" "Insert ð" (insert "<#00F0>"))
+  ("dj" "Insert <#0111>" (insert "<#0111>"))
+  ("i" "Insert " (insert ""))
+  ("j" "Insert <#0237>" (insert "<#0237>"))
+  ("l" "Insert <#0142>" (insert "<#0142>"))
+  ("ng" "Insert <#014B>" (insert "<#014B>"))
+  ("o" "Insert <#00F8>" (insert "<#00F8>"))
+  ("oe" "Insert oe" (emulate-keyboard "S-F5 o e"))
   ("ss" "Insert " (emulate-keyboard "S-F5 s"))
-  ("AA" "Insert AA" (emulate-keyboard "abovering A"))
-  ("OE" "Insert OE" (emulate-keyboard "S-F5 O E"))
+  ("sz" "Insert " (emulate-keyboard "S-F5 s"))
+  ("th" "Insert <#00FE>" (insert "<#00FE>"))
+  ("AA" "Insert " (insert ""))
   ("AE" "Insert AE" (emulate-keyboard "S-F5 A"))
+  ("DH" "Insert Ð" (insert "<#00D0>"))
+  ("L" "Insert <#0141>" (insert "<#0141>"))
+  ("NG" "Insert <#014A>" (insert "<#014A>"))
+  ("O" "Insert <#00D8>" (insert "<#00D8>"))
+  ("OE" "Insert OE" (emulate-keyboard "S-F5 O E"))
+  ("S" "Insert <#00A7>" (insert "<#00A7>"))
   ("SS" "Insert SS" (emulate-keyboard "S-F5 S"))
+  ("TH" "Insert <#00DE>" (insert "<#00DE>"))
 
   ("arccos" "Insert arccos" (insert "arccos"))
   ("arcsin" "Insert arcsin" (insert "arcsin"))
@@ -262,48 +275,48 @@
   ("left)" "Insert large left )" (math-bracket-open ")" "(" #t))
   ("left[" "Insert large [" (math-bracket-open "[" "]" #t))
   ("left]" "Insert large left ]" (math-bracket-open "]" "[" #t))
-  ("left{" "Insert large {" (math-bracket-open "{" "}" #t))
-  ("left}" "Insert large left }" (math-bracket-open "}" "{" #t))
-  ("leftlfloor" "Insert large <lfloor>"
-   (math-bracket-open "lfloor" "rfloor" #t))
-  ("leftrfloor" "Insert large left <rfloor>"
-   (math-bracket-open "rfloor" "lfloor" #t))
-  ("leftlceil" "Insert large <lceil>"
-   (math-bracket-open "lceil" "rceil" #t))
-  ("leftrceil" "Insert large left <rceil>"
-   (math-bracket-open "rceil" "lceil" #t))
-  ("leftlangle" "Insert large <langle>"
-   (math-bracket-open "langle" "rangle" #t))
-  ("leftrangle" "Insert large left <rangle>"
-   (math-bracket-open "rangle" "langle" #t))
+  ("left\\{" "Insert large {" (math-bracket-open "{" "}" #t))
+  ("left\\}" "Insert large left }" (math-bracket-open "}" "{" #t))
+  ("left\\lfloor" "Insert large <lfloor>"
+   (math-bracket-open "<lfloor>" "<rfloor>" #t))
+  ("left\\rfloor" "Insert large left <rfloor>"
+   (math-bracket-open "<rfloor>" "<lfloor>" #t))
+  ("left\\lceil" "Insert large <lceil>"
+   (math-bracket-open "<lceil>" "<rceil>" #t))
+  ("left\\rceil" "Insert large left <rceil>"
+   (math-bracket-open "<rceil>" "<lceil>" #t))
+  ("left\\langle" "Insert large <langle>"
+   (math-bracket-open "<langle>" "<rangle>" #t))
+  ("left\\rangle" "Insert large left <rangle>"
+   (math-bracket-open "<rangle>" "<langle>" #t))
   ("left|" "Insert large left <mid>" (math-bracket-open "|" "|" #t))
   ("left||" "Insert large left <parallel>" (math-bracket-open "||" "||" #t))
   ("left/" "Insert large left /" (math-bracket-open "/" "\\" #t))
-  ("leftbackslash" "Insert large left \\" (math-bracket-open "\\" "/" #t))
+  ("left\\" "Insert large left \\" (math-bracket-open "\\" "/" #t))
   ("left." "Insert large left ." (math-bracket-open "." "." #t))
 
   ("right(" "Insert large right (" (math-bracket-close "(" ")" #t))
   ("right)" "Insert large )" (math-bracket-close ")" "(" #t))
   ("right[" "Insert large right [" (math-bracket-close "[" "]" #t))
   ("right]" "Insert large ]" (math-bracket-close "]" "[" #t))
-  ("right{" "Insert large right {" (math-bracket-close "{" "}" #t))
-  ("right}" "Insert large }" (math-bracket-close "}" "{" #t))
-  ("rightlfloor" "Insert large right <lfloor>"
-   (math-bracket-close "lfloor" "rfloor" #t))
-  ("rightrfloor" "Insert large <rfloor>"
-   (math-bracket-close "rfloor" "lfloor" #t))
-  ("rightlceil" "Insert large right <lceil>"
-   (math-bracket-close "lceil" "rceil" #t))
-  ("rightrceil" "Insert large <rceil>"
-   (math-bracket-close "rceil" "lceil" #t))
-  ("rightlangle" "Insert large right <langle>"
-   (math-bracket-close "langle" "rangle" #t))
-  ("rightrangle" "Insert large <rangle>"
-   (math-bracket-close "rangle" "langle" #t))
+  ("right\\{" "Insert large right {" (math-bracket-close "{" "}" #t))
+  ("right\\}" "Insert large }" (math-bracket-close "}" "{" #t))
+  ("right\\lfloor" "Insert large right <lfloor>"
+   (math-bracket-close "<lfloor>" "<rfloor>" #t))
+  ("right\\rfloor" "Insert large <rfloor>"
+   (math-bracket-close "<rfloor>" "<lfloor>" #t))
+  ("right\\lceil" "Insert large right <lceil>"
+   (math-bracket-close "<lceil>" "<rceil>" #t))
+  ("right\\rceil" "Insert large <rceil>"
+   (math-bracket-close "<rceil>" "<lceil>" #t))
+  ("right\\langle" "Insert large right <langle>"
+   (math-bracket-close "<langle>" "<rangle>" #t))
+  ("right\\rangle" "Insert large <rangle>"
+   (math-bracket-close "<rangle>" "<langle>" #t))
   ("right|" "Insert large right <mid>" (math-bracket-close "|" "|" #t))
   ("right||" "Insert large right <parallel>" (math-bracket-close "||" "||" #t))
   ("right/" "Insert large right /" (math-bracket-close "/" "\\" #t))
-  ("rightbackslash" "Insert large right \\" (math-bracket-close "\\" "/" #t))
+  ("right\\" "Insert large right \\" (math-bracket-close "\\" "/" #t))
   ("right." "Insert large right ." (math-bracket-close "." "." #t))
 
   ("rmfamily" "Use roman font family" (make-with "font-family" "rm"))
@@ -341,7 +354,8 @@
   ("Bbb" "Use blackboard bold font" (make-with "font" "Bbb*"))
   ("mathcal" "Use calligraphic font" (make-with "font" "cal"))
   ("mathfrak" "Use fraktur font" (make-with "font" "Euler"))
-  ("mathbb" "Use blackboard math font" (make-with "font" "Bbb*"))
+  ("mathbb" "Use blackboard math font" (make-with "font" "Bbb"))
+  ("mathbbm" "Use blackboard math font" (make-with "font" "Bbb*"))
   ("mathrm" "Use roman font family" (make-with "font-family" "rm"))
   ("mathtt" "Use typewriter font family" (make-with "font-family" "tt"))
   ("mathsf" "Use sans serif font family" (make-with "font-family" "ss"))
@@ -381,7 +395,7 @@
   ("label" "Make label" (make-label))
   ("ref" "Make reference" (make 'reference))
   ("pageref" "Make page reference" (make 'pageref))
-  ("footnote" "Insert a footnote" (make-wrapped 'footnote))
+  ("footnote" "Insert a footnote" (make 'footnote))
   ("input" "Include a document" (make 'include)))
 
 (when (not (get-boolean-preference "new style fonts"))
