@@ -29,21 +29,7 @@
 (menu-bind bookmarks-menu)
 (menu-bind test-menu)
 (menu-bind help-icons (if (in-session?) (link session-help-icons)))
-
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-;; The Remote menu
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-
-(menu-bind remote-menu
-  (if (and (null? remote-client-list) (not (server-started?)))
-      (link start-client-menu)
-      ;;---
-      ;;(link start-server-menu)
-      )
-  (if (and (null? remote-client-list) (server-started?))
-      (link server-menu))
-  (if (nnull? remote-client-list)
-      (link client-menu)))
+(menu-bind comment-menu)
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; The TeXmacs main menu
@@ -64,6 +50,8 @@
           (=> "Source" (link source-menu)))
       (if (with-linking-tool?)
           (=> "Link" (link link-menu)))
+      (if (in-comment?)
+          (=> "Comment" (link comment-menu)))
       (if (in-presentation?)
           (=> "Dynamic" (link dynamic-menu)))
       (if (style-has? "icourse-dtd")
@@ -210,29 +198,34 @@
    (cursor-history-forward))
   (if (in-presentation?)
     /
-    (link dynamic-icons)))
+    (link dynamic-icons))
+  (if (with-remote-tool?)
+    /
+    (link remote-icons))
+)
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; The TeXmacs side tools
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
+(tm-widget (texmacs-side-tools win)
+  (for (tool (window->tools win))
+    (dynamic (texmacs-side-tool win tool)))
+  ===
+  (glue #t #t 300 1))
+
 (tm-define (upward-context-trees t)
   (cond ((tree-is-buffer? t) (list t))
         ((tree-atomic? t) (upward-context-trees (tree-up t)))
         (else (cons t (upward-context-trees (tree-up t))))))
 
-(tm-widget (texmacs-side-tool t)
-  (horizontal
-    (mini #t
+(tm-tool (context-tool win)
+  (:name "Context tool")
+  (for (t (reverse (upward-context-trees (cursor-tree))))
+    ===
+    (horizontal
       ((eval (symbol->string (tree-label t)))
-       (tree-select t)))
-    >>>))
-
-(tm-widget (texmacs-side-tools)
-  (for (t (upward-context-trees (cursor-tree)))
-    (dynamic (texmacs-side-tool t))
-    ===)
-  (glue #t #t 100 0))
+       (tree-select t)))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; The TeXmacs bottom tools
