@@ -35,6 +35,10 @@
   (set-message "Restart in order to let the new look and feel take effect"
                "configure look and feel"))
 
+(define (notify-gui-theme var val)
+  (set-message "Restart in order to let the new theme take effect"
+               "graphical interface theme"))
+
 (define (notify-language var val)
   (set-output-language val)
   (if (and (current-view) (== (buffer-tree) (stree->tree '(document ""))))
@@ -73,6 +77,12 @@
 (define (notify-new-page-breaking var val)
   (noop))
 
+(define (get-default-native-menubar)
+  (if (qt4-gui?) "on" "off"))
+
+(define (get-default-unified-toolbar)
+  (if (qt4-gui?) "on" "off"))
+
 (define-preferences
   ("profile" "beginner" (lambda args (noop)))
   ("look and feel" "default" notify-look-and-feel)
@@ -82,6 +92,7 @@
   ("complex actions" "popups" noop)
   ("interactive questions" (get-default-interactive-questions) noop)
   ("language" (get-locale-language) notify-language)
+  ("gui theme" "default" notify-gui-theme)
   ("page medium" "paper" (lambda args (noop)))
   ("fast environments" "on" notify-fast-environments)
   ("show full context" "on" (lambda args (noop)))
@@ -116,7 +127,10 @@
   ("bitmap effects" "on" notify-tool)
   ("new style page breaking" "on" notify-new-page-breaking)
   ("open console on errors" "on" noop)
-  ("open console on warnings" "on" noop))
+  ("open console on warnings" "on" noop)
+  ("gui:line-input:autocommit" "on" noop)
+  ("use native menubar" (get-default-native-menubar) noop)
+  ("use unified toolbar" (get-default-unified-toolbar) noop))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Properties of some built-in routines
@@ -149,6 +163,9 @@
 ;; Killing buffers, windows and TeXmacs
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
+(tm-define (buffer-close name)
+  (cpp-buffer-close name))
+
 (tm-define (buffers-modified?)
   (list-or (map buffer-modified? (buffer-list))))
 
@@ -168,17 +185,25 @@
       (:idle 100)
       (buffer-close buf))))
 
+(define (do-kill-window* u)
+ (with buf (window->buffer u)
+   (kill-window u)
+   (delayed
+     (:idle 100)
+     (buffer-close buf))))
+
 (tm-define (safely-kill-window . opt-name)
   (cond ((and (buffer-embedded? (current-buffer)) (null? opt-name))
          (alt-windows-delete (alt-window-search (current-buffer))))
         ((<= (windows-number) 1)
          (safely-quit-TeXmacs))
         ((nnull? opt-name)
-         (with buf (window->buffer (car opt-name))
-           (kill-window (car opt-name))
-           (delayed
-             (:idle 100)
-             (buffer-close buf))))
+         (if (buffer-modified? (window->buffer (car opt-name)))
+             (user-confirm
+                 "The document has not been saved. Really close it?" #f
+               (lambda (answ)
+                 (when answ (do-kill-window* (car opt-name)))))
+             (do-kill-window* (car opt-name))))
         ((buffer-modified? (current-buffer))
          (user-confirm "The document has not been saved. Really close it?" #f
            (lambda (answ)
