@@ -80,8 +80,14 @@
 	    ((== l 'doc-title-options)
 	     (tree-insert! t pos `((,l))))
 	    ((in? l doc-data-inactive-tags)
-	     (tree-insert! t pos `((doc-inactive (,l ""))))
-	     (tree-go-to t pos 0 0 0))
+             (let* ((r (tree-search t (cut tree-is? <> l)))
+                    (x (and (pair? r) (car r))))
+               (cond ((not x)
+                      (tree-insert! t pos `((doc-inactive (,l ""))))
+                      (tree-go-to t pos 0 0 0))
+                     (else
+                      (tree-set! x `(doc-inactive ,x))
+                      (tree-go-to x 0 0 :end)))))
 	    (else
 	     (tree-insert! t pos `((,l "")))
 	     (tree-go-to t pos 0 0))))))
@@ -158,6 +164,24 @@
   (:require (tree-is? t 'doc-inactive))
   (doc-data-activate-here))
 
+(tm-define (doc-data-clean t)
+  (for (c (reverse (tree-children t)))
+    (cond ((tree-empty? c)
+           (tree-remove t (tree-index c) 1))
+          ((and (tree-func? c 'doc-author 1)
+                (tree-empty? (tree-ref c 0)))
+           (tree-remove t (tree-index c) 1))
+          ((and (tree-func? c 'doc-author 1)
+                (tm-is? (tree-ref c 0) 'author-data))
+           (doc-data-clean (tree-ref c 0))))))
+
+(tm-define (kbd-remove t forwards?)
+  (:require (tree-search-upwards t 'doc-data))
+  (with d (tree-search-upwards t 'doc-data)
+    (former t forwards?)
+    (when (and (tree->path d) (tree-is? d 'doc-data))
+      (doc-data-clean d))))
+
 (tm-define (set-doc-title-options opts)
   (with-innermost t 'doc-data
     (with opts-trees (select t '(doc-title-options))
@@ -271,6 +295,11 @@
 	   (with sp (path-previous-section bt bp)
 	     (and (!= sp bp) (path->tree (append (tree->path bt) sp))))))))
 
+(tm-define (go-to-section-title)
+  (and-with s (previous-section)
+    (when (or (section-tag? (tm-car s)) (section*-tag? (tm-car s)))
+      (tree-go-to s 0 :start))))
+
 (define (selection-trim-ending)
   (if (selection-active-any?)
     (with st (selection-tree)
@@ -318,8 +347,14 @@
   (tree-go-to t :end)
   (make 'label))
 
+(tm-define (focus-label t)
+  (:require (section-context? t))
+  (and-with p (tree-up t)
+    (and (tm-func? p 'concat)
+         (focus-search-label p))))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-;; Routines for lists, enumerations and description
+;; Routines for lists, enumerations and descriptions
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (tm-define (list-context? t)
@@ -358,6 +393,13 @@
   (:require (tree-is? t 'item*))
   (go-end-of 'item*))
 
+(tm-define (focus-label t)
+  (:require (or (list-context? t) (tree-is? t 'bib-list)))
+  (and-with doc (tree-down t)
+    (and (tree-is? doc 'document)
+         (and-with par (tree-down doc)
+           (focus-search-label par)))))
+
 (tm-define (numbered-context? t)
   (:require (or (itemize-context? t) (enumerate-context? t)))
   #t)
@@ -376,16 +418,49 @@
 
 (tm-define (standard-parameters l)
   (:require (== l "itemize"))
-  (cons "itemize-levels" (search-parameters "itemize-1")))
+  (list-remove (cons* "itemize-levels"
+                      "item-tag" "item-1" "item-2" "item-3" "item-4"
+                      (search-parameters "itemize-1"))
+               "itemize-level"))
+
+(ahash-set! inhibit-global-table "item-tag" #t)
+(ahash-set! inhibit-local-table "item-1" #t)
+(ahash-set! inhibit-local-table "item-2" #t)
+(ahash-set! inhibit-local-table "item-3" #t)
+(ahash-set! inhibit-local-table "item-4" #t)
 
 (tm-define (standard-parameters l)
   (:require (== l "enumerate"))
-  (cons "enumerate-levels" (search-parameters "enumerate-1")))
+  (list-remove (cons* "enumerate-levels"
+                      "enum-tag" "enum-1" "enum-2" "enum-3" "enum-4"
+                      (search-parameters "enumerate-1"))
+               "enumerate-level"))
+
+(ahash-set! inhibit-global-table "enum-tag" #t)
+(ahash-set! inhibit-local-table "enum-1" #t)
+(ahash-set! inhibit-local-table "enum-2" #t)
+(ahash-set! inhibit-local-table "enum-3" #t)
+(ahash-set! inhibit-local-table "enum-4" #t)
 
 (tm-define (parameter-choice-list l)
   (:require (in? l (list "itemize-levels" "enumerate-levels")))
   (list "1" "2" "3" "4"))
 
+(tm-define (parameter-choice-list l)
+  (:require (in? l (list "item-tag" "item-1" "item-2" "item-3" "item-4")))
+  (list "<bullet>" "<circ>" "<minus>" "<cdot>" "*"
+        "<rightarrow>" "<Rightarrow>"
+        "<triangleright>" "<blacktriangleright>" :other))
+
+(tm-define (parameter-choice-list l)
+  (:require (in? l (list "enum-tag" "enum-1" "enum-2" "enum-3" "enum-4")))
+  (list (list "1, 2, 3, ..." '(macro "x" (arg "x")))
+        (list "a, b, c, ..." '(macro "x" (number (arg "x") "alpha")))
+        (list "A, B, C, ..." '(macro "x" (number (arg "x") "Alpha")))
+        (list "i, ii, iii, ..." '(macro "x" (number (arg "x") "roman")))
+        (list "I, II, III, ..." '(macro "x" (number (arg "x") "Roman")))
+        :other))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Hyphenation
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -399,7 +474,7 @@
     (insert ins)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-;; Inserting formulas
+;; Formulas
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (tm-define (make-equation)
@@ -417,6 +492,21 @@
   (make 'eqnarray*)
   (temp-proof-fix))
 
+(tm-define (focus-label t)
+  (:require (tree-is? t 'equation))
+  (focus-list-search-label (tree-children t)))
+
+(define (down-to-row t)
+  (cond ((not (tree? t)) #f)
+        ((tree-is? t 'row) t)
+        ((tree-in? t '(document tformat table)) (down-to-row (tree-down t)))
+        (else #f)))
+
+(tm-define (focus-label t)
+  (:require (tree-in? t '(eqnarray eqnarray*)))
+  (and-with row (down-to-row (tree-down t))
+    (focus-search-label row)))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Routines for inserting miscellaneous content
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -505,6 +595,11 @@
   (tree-go-to t :last :start)
   (make 'dueto))
 
+(tm-define (focus-label t)
+  (:require (tree-in? t (enunciation-tag-list)))
+  (and (== (tree-arity t) 1)
+       (focus-search-label (tree-ref t 0))))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Editing algorithms
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -584,6 +679,10 @@
 	  (tree-insert! t (- (tree-arity t) 1) '((document "")))
 	  (tree-go-to t (- (tree-arity t) 2) :start)))))
 
+(tm-define (focus-label t)
+  (:require (algorithm-context? t))
+  (focus-list-search-label (tree-children t)))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Possible to use a custom note symbol
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -797,6 +896,9 @@
 (tm-define (footnote-context? t)
   (tree-in? t '(footnote wide-footnote)))
 
+(tm-define (figure-context? t)
+  (tree-in? t (figure-tag-list)))
+
 (tm-define (float-or-footnote-context? t)
   (tree-in? t '(float wide-float footnote wide-footnote)))
 
@@ -911,3 +1013,7 @@
   (if (cursor-at-anchor?)
       (go-to-float)
       (go-to-anchor)))
+
+(tm-define (focus-label t)
+  (:require (or (footnote-context? t) (figure-context? t)))
+  (focus-list-search-label (tree-children t)))
