@@ -14,7 +14,8 @@
 (texmacs-module (text text-menu)
   (:use (text text-edit)
         (text text-structure)
-        (generic document-menu)))
+        (generic document-menu)
+        (generic document-style)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; The Format menu in text mode
@@ -37,8 +38,9 @@
   (group "Paragraph")
   (link paragraph-menu)
   ---
-  (group "Page")
-  (link page-menu))
+  (when (in-main-flow?)
+    (group "Page")
+    (link page-menu)))
 
 (menu-bind compressed-text-format-menu
   (if (new-fonts?)
@@ -46,7 +48,8 @@
   (if (not (new-fonts?))
       (-> "Font" (link text-font-menu)))
   ("Paragraph" (open-paragraph-format))
-  ("Page" (open-page-format))
+  (when (in-main-flow?)
+    ("Page" (open-page-format)))
   (when (inside? 'table)
     ("Cell" (open-cell-properties))
     ("Table" (open-table-properties)))
@@ -54,6 +57,8 @@
   (-> "Whitespace" (link space-menu))
   (-> "Indentation" (link indentation-menu))
   (-> "Break" (link break-menu))
+  (when (and (selection-active-small?) (tm-atomic? (selection-tree)))
+    ("Hyphenate as" (interactive hyphenate-selection-as)))
   ---
   (-> "Color"
       (if (== (get-preference "experimental alpha") "on")
@@ -61,8 +66,12 @@
           ---)
       (link color-menu))
   (-> "Adjust" (link adjust-menu))
+  (-> "Transform" (link linear-transform-menu))
   (-> "Specific" (link specific-menu))
-  (-> "Special" (link format-special-menu)))
+  (-> "Special" (link format-special-menu))
+  (-> "Font effects" (link text-font-effects-menu))
+  (assuming (== (get-preference "bitmap effects") "on")
+    (-> "Graphical effects" (link text-effects-menu))))
 
 (menu-bind text-format-menu
   (if (use-menus?)
@@ -118,7 +127,7 @@
   ("Subsection" (make-section 'subsection))
   ("Subsubsection" (make-section 'subsubsection))
   ---
-  ("Paragraph" (make-section 'paragraph))
+  ("Paragraph::section" (make-section 'paragraph))
   ("Subparagraph" (make-section 'subparagraph)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -146,9 +155,9 @@
       ---)
   ("Exercise" (make 'exercise))
   ("Problem" (make 'problem))
-  ("Solution" (make 'solution))
   ("Question" (make 'question))
-  ("Answer" (make 'answer)))
+  ("Solution" (make 'solution*))
+  ("Answer" (make 'answer*)))
 
 (menu-bind prominent-menu
   ("Quote" (make 'quote-env))
@@ -157,11 +166,17 @@
   ---
   ("Indent" (make 'indent))
   ("Jump in" (make 'jump-in))
-  ("Compact" (make 'compact))
   ---
-  ("Centered" (make 'center))
-  ("Left aligned" (make 'left-aligned))
-  ("Right aligned" (make 'right-aligned))
+  ("Centered" (make 'padded-center))
+  ("Left aligned" (make 'padded-left-aligned))
+  ("Right aligned" (make 'padded-right-aligned))
+  (with s (get-env "par-par-sep")
+    (assuming (and (not (string-ends? s "fns"))
+                   (not (string-starts? s "0fn")))
+      ---
+      ("Compact" (make 'compact))
+      ("Compressed" (make 'compressed))
+      ("Amplified" (make 'amplified))))
   ---
   ("Padded" (make 'padded))
   ("Overlined" (make 'overlined))
@@ -169,34 +184,65 @@
   ("Lines around" (make 'bothlined))
   ("Framed" (make 'framed))
   ("Ornamented" (make 'ornamented))
-  (if (style-has? "ornaments-dtd")
+  ---
+  (-> "Material"
+      ("Manila paper" (make* 'manila-paper "ornaments"))
+      ("Rough paper" (make* 'rough-paper "ornaments"))
+      ("Ridged paper" (make* 'ridged-paper "ornaments"))
+      ("Pine" (make* 'pine "ornaments"))
+      ("Granite" (make* 'granite "ornaments"))
+      ("Metal" (make* 'metal "ornaments")))
+  (-> "Art frame"
+      ("Carved wood" (make* 'carved-wood-frame "std-frame"))
+      ("Decorated wood" (make* 'decorated-wood-frame "std-frame"))
+      ("Black floral I" (make* 'black-floral1-frame "std-frame"))
+      ("Black floral II" (make* 'black-floral2-frame "std-frame")))
+  (-> "Shadow"
+      (group "Contour")
+      ("Drop" (make* 'drop-contour "std-shadow"))
+      ("Bend in" (make* 'bend-in-contour "std-shadow"))
+      ("Bend out" (make* 'bend-out-contour "std-shadow"))
+      ("Bend diagonal" (make* 'diagonal-bend-in-contour "std-shadow"))
       ---
-      ("Manila paper" (make 'manila-paper))
-      ("Rough paper" (make 'rough-paper))
-      ("Ridged paper" (make 'ridged-paper))
-      ("Pine" (make 'pine))
-      ("Granite" (make 'granite))
-      ("Metal" (make 'metal))))
+      (group "South east")
+      ("Drop" (make* 'drop-shadow "std-shadow"))
+      ("Bend in" (make* 'bend-in-shadow "std-shadow"))
+      ("Bend out" (make* 'bend-out-shadow "std-shadow"))
+      ("Bend bottom" (make* 'half-bend-in-shadow "std-shadow"))
+      ("Bend corner" (make* 'quarter-bend-in-shadow "std-shadow"))
+      ---
+      (group "South")
+      ("Drop" (make* 'drop-down "std-shadow"))
+      ("Bend bottom" (make* 'half-bend-in-down "std-shadow"))))
 
 (menu-bind code-menu
   ("Algorithm" (make 'algorithm))
   ("Pseudo code" (make 'render-code))
   ---
   ("Indent" (make 'indent))
-  ("Tabbed" (make 'tabbed))
+  (when (not (selection-active?))
+    ("Tabbed" (make 'wide-tabbed)))
   ---
   (-> "Inline code"
       ("C++" (make 'cpp))
+      ("Fortran" (make 'fortran))
+      ("Java" (make 'java))
       ("Mathemagix" (make 'mmx))
       ("Python" (make 'python))
+      ("R" (make 'r))
+      ("Scala" (make 'scala))
       ("Scheme" (make 'scm))
       ("Shell" (make 'shell))
       ("Scilab" (make 'scilab))
       ("Verbatim" (make 'verbatim)))
   (-> "Block of code"
       ("C++" (make 'cpp-code))
+      ("Fortran" (make 'fortran-code))
+      ("Java" (make 'java-code))
       ("Mathemagix" (make 'mmx-code))
       ("Python" (make 'python-code))
+      ("R" (make 'r-code))
+      ("Scala" (make 'scala-code))
       ("Scheme" (make 'scm-code))
       ("Shell" (make 'shell-code))
       ("Scilab" (make 'scilab-code))
@@ -208,16 +254,30 @@
 
 (menu-bind note-menu
   (when (not (or (inside? 'float) (inside? 'footnote)))
-    ("Footnote" (make 'footnote))
-    ("Marginal note" (make-marginal-note))
-    ;;("Balloon" (make-balloon))
+    (when (in-main-flow?)
+      ("Footnote" (make 'footnote))
+      (when (not (selection-active-non-small?))
+        ("Marginal note" (make-marginal-note))))
+    ("Balloon" (make-balloon))
     ---
-    ("Floating object" (make-insertion "float"))
-    ("Floating figure" (begin (make-insertion "float") (make 'big-figure)))
-    ("Floating table" (begin (make-insertion "float")
-                             (insert-go-to '(big-table "" "") '(0 0))
-                             (make 'tabular)))
-    ("Floating algorithm" (begin (make-insertion "float") (make 'algorithm)))))
+    (when (in-main-flow?)
+      ("Floating object" (make-insertion "float"))
+      (when (not (selection-active-non-small?))
+        ("Floating phantom" (insert '(phantom-float "float" "hf"))))
+      (when (not (selection-active-non-small?))
+        ("Floating figure"
+         (wrap-selection-small
+           (make-insertion "float")
+           (insert-go-to '(big-figure "" (document "")) '(0 0))))
+        ("Floating table"
+         (wrap-selection-small
+           (make-insertion "float")
+           (insert-go-to '(big-table "" (document "")) '(0 0))
+           (make 'tabular))))
+      ("Floating algorithm"
+       (wrap-selection-any
+         (make-insertion "float")
+         (make 'algorithm))))))
 
 (menu-bind position-marginal-note-menu
   (group "Horizontal position")
@@ -235,31 +295,50 @@
 (tm-define (marginal-note-context? t)
   (tree-is? t 'marginal-note))
 
-(tm-menu (focus-position-float-menu t)
+(tm-menu (focus-float-menu t)
   (:require (marginal-note-context? t))
   ---
   (link position-marginal-note-menu)
   ---)
 
-(menu-bind position-float-menu
+(menu-bind float-menu
   ("Top" (toggle-insertion-positioning "t"))
   ("Here" (toggle-insertion-positioning "h"))
   ("Bottom" (toggle-insertion-positioning "b"))
-  ("Other pages" (toggle-insertion-positioning-not "f")))
+  ("Other pages" (toggle-insertion-positioning-not "f"))
+  (if (tree-innermost float-context? #t)
+      ---
+      ("Make non floating"
+       (turn-non-floating (tree-innermost float-context? #t)))))
 
-(tm-define (float-context? t)
-  (cond ((tree-is? t 'float) #t)
-        ((tree-in? t '(big-figure big-figure*
-                       big-table big-table*
-                       algorithm algorithm*
-                       document concat))
-         (and (tree-up t) (float-context? (tree-up t))))
-        (else #f)))
+(tm-menu (focus-float-menu t)
+  (:require (rich-float-context? t))
+  (if (in-multicol-style?)
+      ("Wide float" (float-toggle-wide (focus-tree))))
+  (-> "Allowed positions" (link float-menu))
+  (if (cursor-at-anchor?)
+      ("Go to float" (go-to-float)))
+  (if (not (cursor-at-anchor?))
+      ("Go to anchor" (go-to-anchor))))
 
-(tm-menu (focus-position-float-menu t)
-  (:require (float-context? t))
-  (-> "Allowed positions"
-      (link position-float-menu)))
+(tm-menu (focus-float-menu t)
+  (:require (phantom-float-context? t))
+  (-> "Allowed positions" (link float-menu)))
+
+(tm-menu (focus-float-menu t)
+  (:require (floatable-context? t))
+  (if (in-multicol-style?)
+      ("Span over all columns" (floatable-toggle-wide t)))
+  ("Make floating" (turn-floating (tree-innermost floatable-context?))))
+
+(tm-menu (focus-float-menu t)
+  (:require (tree-is? t 'footnote))
+  (if (in-multicol-style?)
+      ("Wide footnote" (float-toggle-wide (focus-tree))))
+  (if (cursor-at-anchor?)
+      ("Go to footnote" (go-to-float)))
+  (if (not (cursor-at-anchor?))
+      ("Go to anchor" (go-to-anchor))))
 
 (menu-bind position-balloon-menu
   (group "Horizontal alignment")
@@ -276,7 +355,7 @@
   ("Inner top" (set-balloon-valign "top"))
   ("Outer top" (set-balloon-valign "Top")))
 
-(tm-menu (focus-position-float-menu t)
+(tm-menu (focus-float-menu t)
   (:require (balloon-context? t))
   ---
   (link position-balloon-menu)
@@ -295,7 +374,8 @@
   ("Name" (make 'name))
   ("Person" (make 'person))
   ("Cite" (make 'cite*))
-  ("Abbreviation" (make 'abbr))
+  (when (not (selection-active-non-small?))
+    ("Abbreviation" (make 'abbr)))
   ("Acronym" (make 'acronym))
   ---
   ("Verbatim" (make 'verbatim))
@@ -398,6 +478,11 @@
   ("Long" (make-tmlist 'description-long))
   ("Paragraphs" (make-tmlist 'description-paragraphs)))
 
+(menu-bind lists-menu
+  (-> "Itemize" (link itemize-menu))
+  (-> "Enumerate" (link enumerate-menu))
+  (-> "Description" (link description-menu)))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Automatically generated content
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -407,7 +492,10 @@
   (assuming (get-boolean-preference "gui:new bibliography dialogue")
     ("Bibliography" (interactive open-bibliography-inserter)))
   (assuming (not (get-boolean-preference "gui:new bibliography dialogue"))
-    ("Bibliography" (interactive make-bib)))
+    (if (with-database-tool?)
+        ("Bibliography" (make-database-bib)))
+    (if (not (with-database-tool?))
+        ("Bibliography" (choose-file make-bib "Bibliography file" "BibTeX"))))
   ("Index" (make-aux "the-index" "index-prefix" "idx"))
   ("Glossary" (make-aux "the-glossary" "glossary-prefix" "gly"))
   ;;("List of figures" (make-aux* "the-glossary*" "figure-list-prefix" "figure" "List of figures"))
@@ -422,7 +510,8 @@
 (menu-bind text-block-menu
   (if (and (style-has? "header-title-dtd")
            (not (style-has? "header-letter-dtd"))
-           (not (style-has? "header-exam-dtd")))
+           (not (style-has? "header-exam-dtd"))
+           (not (in-poster?)))
       (-> "Title" (link title-menu)))
   (if (style-has? "header-letter-dtd")
       (-> "Header" (link letter-header-menu)))
@@ -446,9 +535,9 @@
       (-> "Automatic" (link automatic-menu)))
   (if (style-has? "std-list-dtd")
       ---
-      (-> "Itemize" (link itemize-menu))
-      (-> "Enumerate" (link enumerate-menu))
-      (-> "Description" (link description-menu))))
+      (link lists-menu)))
+
+(menu-bind text-extra-menu)
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Text menus for inserting inline content
@@ -469,6 +558,7 @@
 
 (menu-bind text-menu
   (link text-block-menu)
+  (link text-extra-menu)
   ---
   (link text-inline-menu)
   ---
@@ -489,16 +579,24 @@
       (=> (balloon (icon "tm_chapter.xpm") "Start a new chapter")
           (link chapter-menu)))
   (if (and (style-has? "section-base-dtd")
-           (not (style-has? "header-exam-dtd")))
+           (not (style-has? "header-exam-dtd"))
+           (not (in-poster?)))
       (=> (balloon (icon "tm_section.xpm") "Start a new section")
           (link section-menu)))
+  (if (in-poster?)
+      (=> (balloon (icon "tm_block.xpm") "Insert a section block")
+          (link poster-block-menu)))
   (if (or (style-has? "env-theorem-dtd")
           (style-has? "header-exam-dtd"))
       (=> (balloon (icon "tm_theorem.xpm") "Insert an enunciation")
           (link enunciation-menu)))
-  (if (style-has? "std-markup-dtd")
+  (if (and (style-has? "std-markup-dtd") (not (in-poster?)))
       (=> (balloon (icon "tm_prominent.xpm") "Insert a prominent piece of text")
           (link prominent-menu)))
+  (if (and (style-has? "std-markup-dtd") (in-poster?))
+      (=> (balloon (icon "tm_var_prominent.xpm")
+                   "Insert a prominent piece of text")
+          (link prominent-menu)))
   (if (style-has? "std-markup-dtd")
       (=> (balloon (icon "tm_program.xpm") "Insert a computer program")
           (link code-menu)))
@@ -517,6 +615,8 @@
                    "Insert automatically generated content")
           (link automatic-menu))))
 
+(menu-bind text-extra-icons)
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Icons for modifying text properties
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -577,11 +677,15 @@
   ;;("Goedenmiddag" (display* "Hi there\n"))
   ;;(mini #t (input (display* answer "\n") "string" '("Hello" "Bonjour") "0.5w"))
   (link text-block-icons)
+  (link text-extra-icons)
   (if (style-has? "std-markup-dtd")
       /)
   (link text-inline-icons)
   (if (in-manual?) (link tmdoc-icons))
-  (link texmacs-insert-icons))
+  (link texmacs-insert-icons)
+  (if (and (in-presentation?) (not (visible-icon-bar? 0)))
+      /
+      (link dynamic-icons)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Focus menus for entering title information
@@ -613,12 +717,10 @@
   ("Subtitle" (make-doc-data-element 'doc-subtitle))
   ("Author" (make-doc-data-element 'doc-author))
   ("Date" (make-doc-data-element 'doc-date))
-  ("Today"
-   (begin (make-doc-data-element 'doc-date) (make 'date 0)))
-  ("Miscellanous" (make-doc-data-element 'doc-misc))
+  ("Today" (begin (make-doc-data-element 'doc-date) (make 'date 0)))
+  ("Miscellaneous" (make-doc-data-element 'doc-misc))
   ("Note" (make-doc-data-element 'doc-note))
-  ("TeXmacs notice" (begin (make-doc-data-element 'doc-note)
-                           (make 'with-TeXmacs-text))))
+  (-> "Cite TeXmacs" (link cite-texmacs-menu)))
 
 (tm-menu (focus-title-hidden-menu)
   ("Running title" (make-doc-data-element 'doc-running-title))
@@ -643,7 +745,9 @@
       (link focus-title-menu)
       (-> "Hidden" (link focus-title-hidden-menu)))
   (=> (balloon (icon "tm_focus_prefs.xpm") "Title presentation options")
-      (link focus-title-option-menu)))
+      (link focus-title-option-menu))
+  (=> (balloon (icon "tm_like.xpm") "Cite TeXmacs")
+      (link cite-texmacs-menu)))
 
 (tm-menu (focus-ancestor-menu t)
   (:require (doc-title-context? t))
@@ -682,7 +786,7 @@
   ("Affiliation" (make-author-data-element 'author-affiliation))
   ("Email" (make-author-data-element 'author-email))
   ("Homepage" (make-author-data-element 'author-homepage))
-  ("Miscellanous" (make-author-data-element 'author-misc))
+  ("Miscellaneous" (make-author-data-element 'author-misc))
   ("Note" (make-author-data-element 'author-note)))
 
 (tm-menu (focus-author-icons)
@@ -760,9 +864,12 @@
   (:require (== l "appendix-prefix"))
   #f)
 
+(define (get-verbatim-section-title s indent?)
+  `(verbatim ,(tm/section-get-title-string s indent?)))
+
 (tm-menu (focus-section-menu)
   (for (s (tree-search-sections (buffer-tree)))
-    ((eval (tm/section-get-title-string s))
+    ((eval (get-verbatim-section-title s #t))
      (when (and (tree->path s) (section-context? s))
        (tree-go-to s 0 :end)))))
 
@@ -773,7 +880,7 @@
 (tm-menu (focus-document-extra-icons t)
   (:require (previous-section))
   (mini #t
-    (=> (eval (tm/section-get-title-string (previous-section)))
+    (=> (eval (get-verbatim-section-title (previous-section) #f))
         (link focus-section-menu))))
 
 (tm-menu (focus-extra-menu t)
@@ -785,16 +892,21 @@
 (tm-menu (focus-extra-icons t)
   (:require (section-context? t))
   (mini #t
-    (=> (eval (tm/section-get-title-string t))
+    //
+    (=> (eval (get-verbatim-section-title t #f))
         (link focus-section-menu))))
 
+(tm-define (child-proposals t i)
+  (:require (and (tree-in? t '(bibliography bibliography*)) (<= i 1)))
+  (if (== i 0) (list "bib" :other) (rcons (bib-standard-styles) :other)))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Focus menu for lists
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (tm-define (standard-options l)
   (:require (in? l (list-tag-list)))
-  (list "compact-list"))
+  (list "compact-list" "triangle-list" "prefix-enumerations"))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Focus menu for theorems and proofs
@@ -804,9 +916,13 @@
   (:require (or (in? l (enunciation-tag-list))
                 (in? l (render-enunciation-tag-list))
                 (in? l '(proof render-proof))))
-  (list "number-europe" ;; "number-us"
-        "number-long-article"
-        "framed-theorems" "hanging-theorems"))
+  (append (list "number-europe" ;; "number-us"
+                "number-long-article"
+                "framed-theorems"
+                "hanging-theorems")
+          (if (style-has? "base-deco-dtd")
+              (list "shadowed-frames")
+              (list))))
 
 (tm-menu (focus-extra-menu t)
   (:require (dueto-supporting-context? t))
@@ -818,7 +934,8 @@
   (:require (dueto-supporting-context? t))
   //
   (when (not (dueto-added? t))
-    ("Due to" (dueto-add t))))
+    (mini #t
+      ("Due to" (dueto-add t)))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Focus menus for algorithms
@@ -861,19 +978,52 @@
 ;; Focus menus for floating objects
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-(tm-menu (focus-position-float-icons t)
+(tm-menu (focus-float-icons t)
   (:require (marginal-note-context? t))
   (=> (balloon (icon "tm_position_float.xpm")
                "Position of marginal note")
       (link position-marginal-note-menu)))
 
-(tm-menu (focus-position-float-icons t)
-  (:require (float-context? t))
+(tm-menu (focus-float-icons t)
+  (:require (rich-float-context? t))
+  (if (in-multicol-style?)
+      ((check (balloon (icon "tm_wide_float.xpm") "Make float wide") "v"
+              (float-wide? (focus-tree)))
+       (float-toggle-wide (focus-tree))))
   (=> (balloon (icon "tm_position_float.xpm")
                "Allowed positions of floating object")
-      (link position-float-menu)))
+      (link float-menu))
+  ((balloon (icon "tm_anchor.xpm")
+            "Go to anchor or float")
+   (cursor-toggle-anchor)))
 
-(tm-menu (focus-position-float-icons t)
+(tm-menu (focus-float-icons t)
+  (:require (phantom-float-context? t))
+  (=> (balloon (icon "tm_position_float.xpm")
+               "Allowed positions of floating object")
+      (link float-menu)))
+
+(tm-menu (focus-float-icons t)
+  (:require (floatable-context? t))
+  (if (in-multicol-style?)
+      ((check (balloon (icon "tm_wide_float.xpm") "Make wide") "v"
+              (floatable-wide? (focus-tree)))
+       (floatable-toggle-wide (focus-tree))))
+  ((balloon (icon "tm_position_float.xpm")
+            "Let the environment float")
+   (turn-floating (tree-innermost floatable-context?))))
+
+(tm-menu (focus-float-icons t)
+  (:require (footnote-context? t))
+  (if (in-multicol-style?)
+      ((check (balloon (icon "tm_wide_float.xpm") "Make footnote wide") "v"
+              (float-wide? (focus-tree)))
+       (float-toggle-wide (focus-tree))))
+  ((balloon (icon "tm_anchor.xpm")
+            "Go to anchor or footnote")
+   (cursor-toggle-anchor)))
+
+(tm-menu (focus-float-icons t)
   (:require (balloon-context? t))
   (=> (balloon (icon "tm_position_float.xpm")
                "Alignment of balloon")
@@ -884,6 +1034,23 @@
                      (append (small-figure-tag-list) (big-figure-tag-list)))))
   (list "captions-above"))
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; Detached notes
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
+(tm-menu (focus-toggle-menu t)
+  (:require (detached-note-context? t))
+  ((check "Named" "v" (custom-note-context? (focus-tree)))
+   (note-toggle-custom t))
+  (dynamic (former t)))
+
+(tm-menu (focus-toggle-icons t)
+  (:require (detached-note-context? t))
+  ((check (balloon (icon "tm_small_textual.xpm") "Use custom note symbol") "v"
+          (custom-note-context? (focus-tree)))
+   (note-toggle-custom t))
+  (dynamic (former t)))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Possibility to rename titled environments
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -917,3 +1084,18 @@
           (frame-titled? (focus-tree)))
    (frame-toggle-title t))
   (dynamic (former t)))
+
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; Renaming automatically generated sections
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
+(tm-menu (focus-toggle-menu t)
+  (:require (automatic-section-context? t))
+  (dynamic (former t))
+  ("Rename" (interactive automatic-section-rename)))
+
+(tm-menu (focus-toggle-icons t)
+  (:require (automatic-section-context? t))
+  (dynamic (former t))
+  ((balloon (icon "tm_small_textual.xpm") "Rename section")
+   (interactive automatic-section-rename)))
