@@ -35,11 +35,14 @@
       (cpp-insert t)
       (cpp-insert-go-to t (path-in t opt-l))))
 
-(tm-define (make tag . opt-arity)
+(define (var-make tag . opt-arity)
   (if (null? opt-arity)
       (cpp-make tag)
       (cpp-make-arity tag (car opt-arity))))
 
+(tm-define (make tag . opt-arity)
+  (apply var-make (cons tag opt-arity)))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Wrappers
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -49,22 +52,35 @@
         ((nstring? val) (insert-go-to `(with ,var ,val "") '(2 0)))
         (else (cpp-make-with var val))))
 
-(tm-define (make-inline lab)
+(tm-define (make lab . opt-arity)
+  (:require (with-like? `(,lab "")))
+  (if (selection-active-any?)
+      (let* ((selection (selection-tree))
+             (ins `(,lab ,selection))
+             (end (path-end selection '())))
+        (clipboard-cut "nowhere")
+        (insert-go-to ins (cons (- (tm-arity ins) 1) end)))
+      (apply former (cons lab opt-arity))))
+
+(tm-define (make lab . opt-arity)
+  (:require (in? lab (make-inline-tag-list)))
   (if (selection-active-large?)
       (with sel `(par-block ,(selection-tree))
 	(clipboard-cut "wrapbuf")
 	(make-return-after)
-	(make lab)
+	(apply var-make (cons lab opt-arity))
 	(tree-set (cursor-tree) sel)
 	(with-innermost t lab
 	  (tree-go-to t :end)
 	  (make-return-before)))
-      (make lab)))
+      (apply var-make (cons lab opt-arity))))
 
-(tm-define (make-wrapped lab)
-  (clipboard-cut "wrapbuf")
-  (make lab)
-  (clipboard-paste "wrapbuf"))
+(tm-define (make lab . opt-arity)
+  (:require (in? lab (make-wrapped-tag-list)))
+  (with sel? (selection-active-any?)
+    (clipboard-cut "wrapbuf")
+    (apply var-make (cons lab opt-arity))
+    (if sel? (clipboard-paste "wrapbuf"))))
 
 (tm-define (insert-go-to t p) (cpp-insert-go-to t p))
 (tm-define (make-hybrid) (cpp-make-hybrid))
@@ -88,3 +104,5 @@
 (tm-define (clipboard-paste cb) (cpp-clipboard-paste cb))
 
 (tm-define (nr-pages) (cpp-nr-pages))
+
+(tm-define (style-clear-cache) (cpp-style-clear-cache))
