@@ -1,4 +1,4 @@
-<TeXmacs|1.99.6>
+<TeXmacs|1.99.19>
 
 <style|source>
 
@@ -24,12 +24,14 @@
     </src-title>
   </active*>
 
-  <use-package|std|env-base|env-math|env-theorem|env-float|header-generic|section-book|title-generic|std-latex|cite-author-year|std-automatic|two-columns>
+  <use-package|std|env|header-generic|section-book|title-generic|std-latex|cite-author-year|std-automatic|two-columns|html-font-size>
 
   <active*|<\src-comment>
     Page layout.
   </src-comment>>
 
+  <assign|par-first|1em>
+
   <assign|parindent|<value|par-first>>
 
   <assign|page-type|a4>
@@ -77,6 +79,8 @@
 
   <assign|section-title|<macro|name|<style-with|src-compact|none|<sectional-short-bold|<vspace*|<tex-len|0.8cm|1ex|0.2ex>><with|font-family|ss|<small|<change-case|<arg|name>|UPCASE>>><vspace|0.5cm>>>>>
 
+  <assign|section-numbered-title|<macro|name|<section-title|<sectional-prefixed|<the-section><section-sep>|<change-case|<arg|name>|UPCASE><section-post-sep>>>>>
+
   <assign|subsection-title|<macro|name|<style-with|src-compact|none|<sectional-normal-bold|<vspace*|<tex-len|0.8cm|1ex|0.2ex>><with|font-family|ss|<small|<arg|name>>><vspace|0.5cm>>>>>
 
   <assign|subsubsection-title|<macro|name|<style-with|src-compact|none|<sectional-normal-bold|<vspace*|<tex-len|0.8cm|1ex|0.2ex>><with|font-family|ss|<small|<arg|name>>><vspace|0.5cm>>>>>
@@ -172,13 +176,21 @@
 
   \;
 
-  <new-list|itemize-1|<value|aligned-item>|<macro|x|<active*|<with|mode|math|<rigid|\<bullet\>>>>>>
+  <assign|item-1|<macro|<active*|<with|mode|math|\<bullet\>>>>>
 
-  <new-list|itemize-2|<value|aligned-item>|<macro|x|<active*|<math|->>>>
+  <assign|item-2|<macro|<active*|<with|mode|math|<rigid|->>>>>
 
-  <new-list|itemize-3|<value|aligned-item>|<macro|x|<active*|<math|\<ast\>>>>>
+  <assign|item-3|<macro|<active*|<math|\<ast\>>>>>
 
-  <new-list|itemize-4|<value|aligned-item>|<macro|x|<active*|<math|\<cdot\>>>>>
+  <assign|item-4|<macro|<active*|<math|\<cdot\>>>>>
+
+  <new-list|itemize-1|<value|aligned-item>|<macro|name|<item-tag>>>
+
+  <new-list|itemize-2|<value|aligned-item>|<macro|name|<item-tag>>>
+
+  <new-list|itemize-3|<value|aligned-item>|<macro|name|<item-tag>>>
+
+  <new-list|itemize-4|<value|aligned-item>|<macro|name|<item-tag>>>
 
   \;
 
@@ -186,6 +198,8 @@
 
   \;
 
+  <assign|left-margin-0|24pt>
+
   <assign|left-margin-1|24pt>
 
   <assign|left-margin-2|20pt>
@@ -200,6 +214,8 @@
 
   \;
 
+  <assign|top-sep-0|<tex-len|10pt|4pt|6pt>>
+
   <assign|top-sep-1|<tex-len|10pt|4pt|6pt>>
 
   <assign|top-sep-2|<tex-len|5pt|2.5pt|1pt>>
@@ -208,6 +224,8 @@
 
   \;
 
+  <assign|par-par-sep-0|<tex-len|5pt|2.5pt|1pt>>
+
   <assign|par-par-sep-1|<tex-len|5pt|2.5pt|1pt>>
 
   <assign|par-par-sep-2|<tex-len|2.5pt|1pt|1pt>>
@@ -218,13 +236,21 @@
 
   <assign|enumerate-level|0>
 
-  <new-list|enumerate-1|<value|aligned-dot-item>|<macro|name|<number|<arg|name>|arabic>>>
+  <assign|enum-1|<macro|name|<number|<arg|name>|arabic>>>
 
-  <new-list|enumerate-2|<value|aligned-item>|<macro|name|(<number|<arg|name>|alpha>)>>
+  <assign|enum-2|<macro|name|<number|<arg|name>|alpha>>>
 
-  <new-list|enumerate-3|<value|aligned-dot-item>|<macro|name|<number|<arg|name>|roman>>>
+  <assign|enum-3|<macro|name|<number|<arg|name>|roman>>>
 
-  <new-list|enumerate-4|<value|aligned-dot-item>|<macro|name|<number|<arg|name>|Alpha>>>
+  <assign|enum-4|<macro|name|<number|<arg|name>|Alpha>>>
+
+  <new-list|enumerate-1|<value|aligned-dot-item>|<macro|name|<enum-tag|<arg|name>>>>
+
+  <new-list|enumerate-2|<value|aligned-item>|<macro|name|<enum-tag|<arg|name>>>>
+
+  <new-list|enumerate-3|<value|aligned-dot-item>|<macro|name|<enum-tag|<arg|name>>>>
+
+  <new-list|enumerate-4|<value|aligned-dot-item>|<macro|name|<enum-tag|<arg|name>>>>
 
   <assign|enumerate-reduce|<macro|nr|<plus|<mod|<minus|<arg|nr>|1>|4>|1>>>
 
@@ -246,10 +272,10 @@
 
   <assign|ruled-tabular*|<macro|body|<with|par-columns|1|<tformat|<twith|table-width|1par>|<cwith|1|1|1|-1|cell-bborder|0.5pt>|<cwith|1|1|1|-1|cell-tborder|1pt>|<cwith|-1|-1|1|-1|cell-bborder|1pt>|<arg|body>>>>>
 
-  <assign|big-table-enlarge|<macro|body|<if|<greater|<times|2|<look-up|<box-info|<arg|body>|w>|0>>|<look-up|<box-info|<space|<tex-text-width>>|w>|0>>|<with|par-columns|1|<arg|body>>|<arg|body>>>>
+  <assign|big-table-enlarge|<macro|contents|body|<if|<greater|<times|2|<look-up|<box-info|<arg|contents>|w>|0>>|<look-up|<box-info|<space|<tex-text-width>>|w>|0>>|<with|par-columns|1|<arg|body>>|<arg|body>>>>
 
   <assign|big-table|<\macro|body|caption>
-    <\big-table-enlarge>
+    <\big-table-enlarge|<arg|body>>
       <\surround|<compound|next-table>|>
         <\render-big-table>
           table
@@ -306,10 +332,22 @@
     </src-comment>
   </active*>
 
+  <assign|bibitem-width|2em>
+
+  <assign|transform-bibitem|<macro|body|[<arg|body>] >>
+
+  <assign|xtransform-bibitem|<macro|body|<rsup|<arg|body>>>>
+
+  <assign|xrender-bibitem|<macro|text|<style-with|src-compact|none|<with|par-first|<minus|1tmpt|<value|bibitem-width>>|<yes-indent>><hspace|<maximum|0cm|<minus|<value|bibitem-width>|<box-info|<arg|text>|w.>>>><arg|text>>>>
+
   <assign|bib-list|<\macro|largest|body>
-    <\with|par-left|1em|par-first|-1em|font-size|1|bibitem-nr|0>
-      <arg|body>
-    </with>
+    <\small>
+      <\with|bibitem-width|<minimum|<box-info|<transform-bibitem|<arg|largest>>.|w.>|2em>|item-hsep|<value|bibitem-hsep>|bibitem-nr|0|par-flexibility|2.0>
+        <\description>
+          <arg|body>
+        </description>
+      </with>
+    </small>
   </macro>>
 
   <assign|bibliography-text|<macro|<rule|9cm|1pt>>>
@@ -320,10 +358,10 @@
     </with>
   </macro>>
 
+  <assign|bibliography-text|<macro|<localize|References>>>
+
   <assign|render-bibliography|<\macro|name|body>
-    <\with|par-columns|1>
-      <center|<section*|<arg|name>>>
-    </with>
+    <section*|<arg|name>>
 
     <arg|body>
   </macro>>
@@ -376,12 +414,14 @@
     </with>
   </macro>>
 
-  <assign|doc-data|<xmacro|args|<with|par-columns|1|<extern|doc-data|<quote-arg|args>|>>>>
+  <assign|doc-data|<xmacro|args|<with|par-columns|1|par-first|0em|<extern|doc-data|<quote-arg|args>|>>>>
 
-  \ <assign|doc-render-title|<macro|x|<\surround|<vspace*|0.5fn>|>
+  <assign|doc-render-title|<macro|x|<\surround|<vspace*|0.5fn>|>
     <doc-title-block|<font-magnify|1.682|<with|math-font-series|bold|font-series|bold|font-family|ss|<arg|x>>>>
   </surround>>>
 
+  <assign|doc-title|<value|doc-render-title>>
+
   <assign|doc-title-block|<macro|body|<arg|body>>>
 
   <assign|doc-authors-data|<\xmacro|data>
